@@ -41,12 +41,20 @@
 #ifdef PLOT_3D
 #include "CMap3D.h"
 #endif
+#include "CDlgExport.h"
+#include "CTabWidget.h"
+#include "COverlayDistance.h"
+#include "COverlayDistanceEditWidget.h"
+
+#include <QtGui>
 
 CActions::CActions(QObject *parent) :
 QObject(parent), parent(parent)
 {
     actionGroup = (CMenus*) parent;
     canvas = theMainWindow->getCanvas();
+
+
     createAction(tr("F1"), ":/icons/iconMap16x16", tr("&Map ..."), "aSwitchToMap", tr("Manage maps."));
     createAction(tr("F2"), ":/icons/iconWaypoint16x16", tr("&Waypoint ..."), "aSwitchToWpt", tr("Manage waypoints."));
     createAction(tr("F3"), ":/icons/iconTrack16x16", tr("&Track ..."), "aSwitchToTrack", tr("Manage tracks."));
@@ -94,17 +102,21 @@ QObject(parent), parent(parent)
     createAction(tr("F8"), ":/icons/iconSelect16x16", tr("&Select Points"), "aSelTrack", tr("Select track points by rectangle."));
     createAction(tr("F9"), ":/icons/iconUpload16x16", tr("U&pload"), "aUploadTrack", tr("Upload tracks to device."));
     createAction(tr("F10"), ":/icons/iconDownload16x16", tr("Down&load"), "aDownloadTrack", tr("Download tracks from device."));
-    createAction(tr("Del"), ":/icons/iconClear16x16", tr("Purge Selection"), "aTrackPurgeSelection", tr("Purge the selected points of the track."));
-    createAction(tr("ctrl+Del"), ":/icons/iconClear16x16", tr("Delete Selection"), "aDeleteTrackSelection", tr("Deletes the selected points of the track."));
+    createAction(tr("ctrl+Del"), ":/icons/iconClear16x16", tr("Hide/Show Selection"), "aTrackPurgeSelection", tr("Toggle visibility of the selected track points."));
+//    createAction(tr("ctrl+Del"), ":/icons/iconClear16x16", tr("Delete Selection"), "aDeleteTrackSelection", tr("Deletes the selected points of the track."));
     //
     createAction(tr("F5"), ":/icons/iconPlayPause16x16", tr("&Start / Stop"), "aLiveLog", tr("Start / stop live log recording."));
     createAction(tr("F6"), ":/icons/iconLock16x16", tr("Move Map to &Pos."), "aLockMap", tr("Move the map to keep the positon cursor centered."));
     createAction(tr("F7"), ":/icons/iconAdd16x16", tr("Add &Waypoint"), "aAddWpt", tr("Add a waypoint at current position."));
     //
 
+    createAction(tr("ESC"), ":/icons/iconBack16x16", tr("&Back"), "aBackToOverlay", tr("Go back to overlay menu."));
     createAction(tr("F5"), ":/icons/iconText16x16", tr("Add Static &Text Box"), "aText", tr("Add text on the map."));
     createAction(tr("F6"), ":/icons/iconTextBox16x16", tr("Add &Geo-Ref. Text Box"), "aTextBox", tr("Add a textbox on the map."));
     createAction(tr("F7"), ":/icons/iconDistance16x16", tr("Add Distance &Polyline"), "aDistance", tr("Add a polyline to measure distances."));
+    createAction(tr("F7"), ":/icons/iconDistance16x16", tr("Distance &Polyline"), "aSwitchToOverlayDistance", tr("Add a polyline to measure distances."));
+    createAction(tr("F5"), ":/icons/iconAdd16x16", tr("Join Distance PolyLines"), "aCombineDistOvl", tr("Join distance polylines to one."));
+
     //
     createAction(tr("F5"), ":/icons/iconDiary16x16", tr("&Diary"), "aDiary", tr("Add / edit diary data"));
     createAction(tr("F6"), ":/icons/iconColorChooser16x16", tr("&Pick Color"), "aColorPicker", tr("test only"));
@@ -121,10 +133,12 @@ QObject(parent), parent(parent)
     createAction(QKeySequence (Qt::ALT + Qt::Key_Right).toString(), ":/icons/editcopy.png", tr("&Move right"), "aMoveRight", tr("Move to the right side."));
     createAction(QKeySequence (Qt::ALT + Qt::Key_Up).toString(), ":/icons/editcopy.png", tr("&Move up"), "aMoveUp", tr("Move up."));
     createAction(QKeySequence (Qt::ALT + Qt::Key_Down).toString(), ":/icons/editcopy.png", tr("&Move down"), "aMoveDown", tr("Move down."));
-    createAction(tr("ctrl+c"), ":/icons/editcopy.png", tr("&Copy"), "aCopyToClipboard", tr("Copy selected trackpoints to clipboard."));
-    createAction(tr("ctrl+v"), ":/icons/editpaste.png", tr("&Paste"), "aPasteFromClipboard", tr("Paste Track."));
-    createAction(tr("ctrl+z"), ":/icons/editpaste.png", tr("&Undo"), "aUndo", tr("Undo a command."));
-    createAction(tr("ctrl+y"), ":/icons/editpaste.png", tr("&Redo"), "aRedo", tr("Redo a command."));
+    createAction("CTRL+c", ":/icons/editcopy.png", tr("&Copy"), "aCopyToClipboard", tr(""));
+    createAction("CTRL+v", ":/icons/editpaste.png", tr("&Paste"), "aPasteFromClipboard", tr(""));
+    createAction("CTRL+z", ":/icons/editundo.png", tr("&Undo"), "aUndo", tr("Undo a command."));
+    createAction("SHIFT+CTRL+z", ":/icons/editredo.png", tr("&Redo"), "aRedo", tr("Redo a command."));
+
+
 }
 
 
@@ -154,9 +168,13 @@ const QString& toolTip)
 
     QString slotName;
     if (actionName.startsWith('a'))
+    {
         slotName = "func" + actionName.mid(1);
+    }
     else
+    {
         slotName = actionName;
+    }
 
     connect(tmpAction, SIGNAL(triggered()), this, QString("1" + slotName + "()").toAscii().data());
 
@@ -167,7 +185,9 @@ QAction *CActions::getAction(const QString& actionObjectName)
 {
     QAction *tmpAction = findChild<QAction *> (actionObjectName);
     if (tmpAction)
+    {
         return tmpAction;
+    }
     else
     {
         qDebug()
@@ -204,7 +224,20 @@ void CActions::funcSwitchToMap()
     // qDebug() << Q_FUNC_INFO;
     setMenuTitle(tr("&Maps"));
     setMenuPixmap(QPixmap(":/icons/backMap128x128"));
+
+#ifdef PLOT_3D
+    if(theMainWindow->getCanvasTab()->currentWidget()->objectName() == "CMap3D")
+    {
+        actionGroup->switchToActionGroup(CMenus::Map3DMenu);
+    }
+    else
+    {
+        actionGroup->switchToActionGroup(CMenus::MapMenu);
+    }
+#else
     actionGroup->switchToActionGroup(CMenus::MapMenu);
+#endif
+
     CMapDB::self().gainFocus();
     funcMoveArea();
 }
@@ -271,6 +304,15 @@ void CActions::funcSwitchToOverlay()
     funcMoveArea();
 }
 
+void CActions::funcSwitchToOverlayDistance()
+{
+    setMenuTitle(tr("&Overlay Distance"));
+    setMenuPixmap(QPixmap(":/icons/backDistance128x128"));
+    actionGroup->switchToActionGroup(CMenus::OverlayDistanceMenu);
+    COverlayDB::self().gainFocus();
+    funcDistance();
+}
+
 
 void CActions::funcSwitchToMainMore()
 {
@@ -363,7 +405,8 @@ void CActions::funcSearchMap()
 
 void CActions::funcUploadMap()
 {
-    CMapDB::self().upload();
+    QStringList keys;
+    CMapDB::self().upload(keys);
 }
 
 
@@ -454,7 +497,13 @@ void CActions::funcImageWpt()
 
 void CActions::funcUploadWpt()
 {
-    CWptDB::self().upload();
+    QStringList keys;
+    CDlgExport dlg(0,&keys,0,0);
+    if( dlg.exec() == QDialog::Rejected)
+    {
+        return;
+    }
+    CWptDB::self().upload(keys);
 }
 
 
@@ -492,7 +541,13 @@ void CActions::funcSelTrack()
 
 void CActions::funcUploadTrack()
 {
-    CTrackDB::self().upload();
+    QStringList keys;
+    CDlgExport dlg(0,0,&keys,0);
+    if( dlg.exec() == QDialog::Rejected)
+    {
+        return;
+    }
+    CTrackDB::self().upload(keys);
 }
 
 
@@ -526,7 +581,13 @@ void CActions::funcDeleteTrackSelection()
 
 void CActions::funcUploadRoute()
 {
-    CRouteDB::self().upload();
+    QStringList keys;
+    CDlgExport dlg(0,0,0,&keys);
+    if( dlg.exec() == QDialog::Rejected)
+    {
+        return;
+    }
+    CRouteDB::self().upload(keys);
 }
 
 
@@ -554,6 +615,11 @@ void CActions::funcAddWpt()
 }
 
 
+void CActions::funcBackToOverlay()
+{
+    funcSwitchToOverlay();
+}
+
 void CActions::funcText()
 {
     canvas->setMouseMode(CCanvas::eMouseAddText);
@@ -571,6 +637,10 @@ void CActions::funcDistance()
     canvas->setMouseMode(CCanvas::eMouseAddDistance);
 }
 
+void CActions::funcCombineDistOvl()
+{
+    COverlayDB::self().combineDistOvl();
+}
 
 void CActions::funcWorldBasemap()
 {
@@ -624,7 +694,36 @@ void CActions::funcMoveDown()
 //    else if (e->key() == Qt::Key_C && e->modifiers() == Qt::ControlModifier)
 void CActions::funcCopyToClipboard()
 {
-    CTrackDB::self().copyToClipboard();
+    IOverlay * ovl = 0;
+    CTrack *   trk = 0;
+
+    ovl = COverlayDB::self().highlightedOverlay();
+    trk = CTrackDB::self().highlightedTrack();
+
+    if(trk && ovl)
+    {
+        bool ok;
+        QStringList items;
+        items << tr("Track") << tr("Overlay");
+        QString res = QInputDialog::getItem(0, tr("What to do?"), tr("I do not know what to copy. Please select:"), items, 0, false, &ok);
+
+        if(res == tr("Track"))
+        {
+            CTrackDB::self().copyToClipboard();
+        }
+        else if(res == tr("Overlay"))
+        {
+            COverlayDB::self().copyToClipboard();
+        }
+    }
+    else if(trk)
+    {
+        CTrackDB::self().copyToClipboard();
+    }
+    else if(ovl)
+    {
+        COverlayDB::self().copyToClipboard();
+    }
 }
 
 
@@ -632,6 +731,7 @@ void CActions::funcCopyToClipboard()
 void CActions::funcPasteFromClipboard()
 {
     CTrackDB::self().pasteFromClipboard();
+    COverlayDB::self().pasteFromClipboard();
 }
 
 
