@@ -59,7 +59,7 @@
 
 #include <QtGui>
 #include "CMenus.h"
-#include "CUndoStack.h"
+#include "CUndoStackView.h"
 #include "CCanvasUndoCommandZoom.h"
 #include "CMapUndoCommandMove.h"
 
@@ -335,6 +335,7 @@ void CCanvas::draw(QPainter& p)
 
     drawRefPoints(p);
     drawScale(p);
+    drawCompass(p);
 
     mouse->draw(p);
 }
@@ -370,12 +371,11 @@ void CCanvas::drawScale(QPainter& p)
 {
     IMap& map = CMapDB::self().getMap();
 
+    double a,b,d;
     int yshift = 0;
     if (QApplication::desktop()->height() < 650) yshift = 60 ;
     QPoint px1(rect().bottomRight() - QPoint(100,50 + yshift));
 
-    if(map.isLonLat()) return;
-
     // step I: get the approximate distance for 200px in the bottom right corner
     double u1 = px1.x();
     double v1 = px1.y();
@@ -386,13 +386,26 @@ void CCanvas::drawScale(QPainter& p)
     map.convertPt2M(u1,v1);
     map.convertPt2M(u2,v2);
 
-    double d = u1 - u2;
+    if(map.isLonLat())
+    {
+        XY p1,p2;
+        double a1,a2;
+        p1.u = u1;
+        p1.v = v1;
+        p2.u = u2;
+        p2.v = v2;
+        d = distance(p1, p2, a1, a2);
+
+    }
+    else
+    {
+        d = u1 - u2;
+        //     qDebug() << log10(d) << d << a << b;
+    }
 
     // step II: derive the actual scale length in [m]
-    double a = (int)log10(d);
-    double b = log10(d) - a;
-
-    //     qDebug() << log10(d) << d << a << b;
+    a = (int)log10(d);
+    b = log10(d) - a;
 
     if(0 <= b && b < log10(3.0f))
     {
@@ -450,16 +463,51 @@ void CCanvas::drawScale(QPainter& p)
 }
 
 
+void CCanvas::drawCompass(QPainter& p)
+{
+    QPolygon arrow;
+
+#define H 60
+#define W 30
+
+    arrow << QPoint(0, -H/2) << QPoint(-W/2, H/2) << QPoint(0, H/3) << QPoint(W/2, H/2);
+
+    p.save();
+
+    p.translate(size().width() - 50, size().height() - 50);
+    p.rotate(-CMapDB::self().getMap().getAngleNorth());
+
+    p.setBrush(Qt::NoBrush);
+    p.setPen(QPen(Qt::white,3));
+    p.drawPolygon(arrow);
+
+    p.setPen(QPen(Qt::black,1));
+    p.setBrush(QColor(150,150,255,100));
+    p.drawPolygon(arrow);
+
+    drawText("N", p, QPoint(0, -H/2));
+    drawText("S", p, QPoint(0, +H/2 + 15));
+
+    p.restore();
+}
+
+
 void CCanvas::drawText(const QString& str, QPainter& p, const QPoint& center, const QColor& color)
 {
-    QFont           f = CResources::self().getMapFont();
-    QFontMetrics    fm(f);
+    CCanvas::drawText(str,p,center, color, CResources::self().getMapFont());
+}
+
+
+void CCanvas::drawText(const QString& str, QPainter& p, const QPoint& center, const QColor& color, const QFont& font)
+{
+
+    QFontMetrics    fm(font);
     QRect           r = fm.boundingRect(str);
 
     r.moveCenter(center);
 
     p.setPen(Qt::white);
-    p.setFont(f);
+    p.setFont(font);
 
     p.drawText(r.topLeft() - QPoint(-1,-1), str);
     p.drawText(r.topLeft() - QPoint( 0,-1), str);
@@ -509,7 +557,7 @@ void CCanvas::wheelEvent(QWheelEvent * e)
 
 void CCanvas::zoom(bool in, const QPoint& p)
 {
-    CUndoStack::getInstance()->push(new CCanvasUndoCommandZoom(in, p));
+    CUndoStackView::getInstance()->push(new CCanvasUndoCommandZoom(in, p));
     update();
 }
 
@@ -521,7 +569,7 @@ void CCanvas::move(double lon, double lat)
     double v = lat * DEG_TO_RAD;
     map.convertRad2Pt(u,v);
 
-    CUndoStack::getInstance()->push(new CMapUndoCommandMove(&map,QPoint(u,v), rect().center()));
+    CUndoStackView::getInstance()->push(new CMapUndoCommandMove(&map,QPoint(u,v), rect().center()));
     update();
 }
 
@@ -569,7 +617,7 @@ void CCanvas::move(move_direction_e dir)
         }
         break;
     }
-    CUndoStack::getInstance()->push(new CMapUndoCommandMove(&map,p1, p2));
+    CUndoStackView::getInstance()->push(new CMapUndoCommandMove(&map,p1, p2));
 
     update();
 }
@@ -589,7 +637,7 @@ void CCanvas::mouseMoveEventCoord(QMouseEvent * e)
     map.convertPt2Rad(x,y);
     map.convertPt2M(x_m,y_m);
 
-    //     qDebug() << x * RAD_TO_DEG << y * RAD_TO_DEG << ">>>" << x_m << y_m;
+    //    qDebug() << x * RAD_TO_DEG << y * RAD_TO_DEG << ">>>" << x_m << y_m;
 
     if((x == e->x()) && (y == e->y()))
     {
