@@ -43,6 +43,8 @@ CCopyright::CCopyright()
         "Marc Feld<br/>"
         "Joerg Wunsch<br/>"
         "Albrecht Dre&szlig;<br/>"
+        "Christian Ehrlicher<br/>"
+        "Christian Treffs<br/>"        
         "</p>"
         "<p>Translation:<br/>"
         "Sarah Neumann (German)<br/>"
@@ -50,6 +52,7 @@ CCopyright::CCopyright()
         "Alessandro Briosi (Italian)<br/>"
         "Mike Markov (Russian)<br/>"
         "Oscar A. (Spanish)<br/>"
+        "Harrie Klomp (Dutch)<br/>"
         "</p>"
         "<p>"
         "Icons and eye candy are from the <b>KDE</b> icon set, the <b>Nuvola</b> icon set and "
