@@ -54,7 +54,7 @@ CCreateMapGeoTiff::CCreateMapGeoTiff(QWidget * parent)
     helpStep1->setHelp(tr("Load Raster Map"),
         tr("This dialog allows you to georeference raster map files. As pre-requisite you need a set of reference points and the projection for those points. You will get best results if the projection of the points is also the projection of the map. In most cases this is mercator. It is recommended to shift the reference point to WGS84 datum, right from the beginning."));
     helpStep2->setHelp(tr("Add Reference Points"),
-        trUtf8("The next stage is to add known reference points. Simply add reference points to the map and enter their latitude / longitude (WGS84) or the easting and northing [m] in the table. Next you move the point to the correct location on the map.\n\ncoordinate formats:\n\xe2\x80\xa2 \"N49\xc2\xb0 10.234 E12\xc2\xb0 01.456\"\n\xe2\x80\xa2 \"12.193172   46.575377\"\n\xe2\x80\xa2 \"285000 5162000\""));
+        trUtf8("The next stage is to add known reference points. Simply add reference points to the map and enter their latitude / longitude (WGS84) or the easting and northing [m] in the table. Next you move the point to the correct location on the map.\n\ncoordinate formats:\n\xe2\x80\xa2 \"N49\xc2\xb0 10.234 E12\xc2\xb0 01.456\"\n\xe2\x80\xa2 \"46.575377   12.193172\"\n\xe2\x80\xa2 \"285000 5162000\""));
     helpStep3->setHelp(tr("Reference Map"),
         tr("Now QLandkarte GT will reference your file with the help of the GDAL tools. Watch the progress in the output browser."));
 
@@ -76,9 +76,11 @@ CCreateMapGeoTiff::CCreateMapGeoTiff(QWidget * parent)
     connect(&cmd, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotFinished(int,QProcess::ExitStatus)));
     connect(pushClearAll, SIGNAL(clicked()), this, SLOT(slotClearAll()));
     connect(toolProjWizard, SIGNAL(clicked()), this, SLOT(slotProjWizard()));
+    connect(toolGCPProjWizard, SIGNAL(clicked()), this, SLOT(slotGCPProjWizard()));
 
     QSettings cfg;
-    lineProjection->setText(cfg.value("create/def.proj","+proj=merc +ellps=WGS84 +datum=WGS84 +no_defs").toString());
+    lineMapProjection->setText(cfg.value("create/mapproj","+proj=merc +ellps=WGS84 +datum=WGS84 +no_defs").toString());
+    lineGCPProjection->setText(cfg.value("create/gcpproj","+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs").toString());
 
     comboMode->addItem(tr("square pixels (2 Ref. Pts.)"), eSquare);
     comboMode->addItem(tr("linear (3 Ref. Pts.)"), eLinear);
@@ -87,11 +89,11 @@ CCreateMapGeoTiff::CCreateMapGeoTiff(QWidget * parent)
     comboMode->setCurrentIndex(1);
 
     toolProjWizard->setIcon(QPixmap(":/icons/iconWizzard16x16.png"));
+    toolGCPProjWizard->setIcon(QPixmap(":/icons/iconWizzard16x16.png"));
 
     theMainWindow->getCanvas()->setMouseMode(CCanvas::eMouseMoveRefPoint);
 }
 
-
 CCreateMapGeoTiff::~CCreateMapGeoTiff()
 {
     if(closemap) CMapDB::self().closeMap();
@@ -192,7 +194,7 @@ void CCreateMapGeoTiff::slotOpenFile()
         OGRSpatialReference oSRS;
         oSRS.importFromWkt(&ptr);
         oSRS.exportToProj4(&ptr);
-        lineProjection->setText(ptr);
+        lineMapProjection->setText(ptr);
 
         gdalGCP2RefPt(dataset->GetGCPs(), dataset->GetGCPCount());
     }
@@ -238,7 +240,7 @@ void CCreateMapGeoTiff::slotReload()
         OGRSpatialReference oSRS;
         oSRS.importFromWkt(&ptr);
         oSRS.exportToProj4(&ptr);
-        lineProjection->setText(ptr);
+        lineMapProjection->setText(ptr);
 
         gdalGCP2RefPt(dataset->GetGCPs(), dataset->GetGCPCount());
     }
@@ -249,6 +251,7 @@ void CCreateMapGeoTiff::slotReload()
 
 void CCreateMapGeoTiff::slotModeChanged(int)
 {
+    helpStep3->setEnabled(treeWidget->topLevelItemCount() >= getNumberOfGCPs());
     pushGoOn->setEnabled(treeWidget->topLevelItemCount() >= getNumberOfGCPs());
 }
 
@@ -279,6 +282,7 @@ void CCreateMapGeoTiff::slotAddRef()
         treeWidget->resizeColumnToContents(i);
     }
 
+    helpStep3->setEnabled(treeWidget->topLevelItemCount() >= getNumberOfGCPs());
     pushGoOn->setEnabled(treeWidget->topLevelItemCount() >= getNumberOfGCPs());
     pushSaveRef->setEnabled(treeWidget->topLevelItemCount() > 0);
 
@@ -298,7 +302,7 @@ void CCreateMapGeoTiff::addRef(double x, double y, double u, double v)
     pt.item->setText(eLonLat,tr(""));
     pt.item->setText(eX,QString::number(pt.x));
     pt.item->setText(eY,QString::number(pt.y));
-    pt.item->setText(eLonLat,QString("%1 %2").arg(u,0,'f',6).arg(v,0,'f',6));
+    pt.item->setText(eLonLat,QString("%1 %2").arg(v,0,'f',6).arg(u,0,'f',6));
 
     treeWidget->addTopLevelItem(pt.item);
 
@@ -308,6 +312,7 @@ void CCreateMapGeoTiff::addRef(double x, double y, double u, double v)
         treeWidget->resizeColumnToContents(i);
     }
 
+    helpStep3->setEnabled(treeWidget->topLevelItemCount() >= getNumberOfGCPs());
     pushGoOn->setEnabled(treeWidget->topLevelItemCount() >= getNumberOfGCPs());
     pushSaveRef->setEnabled(treeWidget->topLevelItemCount() > 0);
 }
@@ -337,6 +342,7 @@ void CCreateMapGeoTiff::slotDelRef()
         refpts.remove(item->data(eLabel,Qt::UserRole).toUInt());
         delete item;
     }
+    helpStep3->setEnabled(treeWidget->topLevelItemCount() >= getNumberOfGCPs());
     pushGoOn->setEnabled(treeWidget->topLevelItemCount() >= getNumberOfGCPs());
     pushSaveRef->setEnabled(treeWidget->topLevelItemCount() > 0);
 
@@ -366,6 +372,7 @@ void CCreateMapGeoTiff::slotLoadRef()
         treeWidget->resizeColumnToContents(i);
     }
 
+    helpStep3->setEnabled(treeWidget->topLevelItemCount() >= getNumberOfGCPs());
     pushGoOn->setEnabled(treeWidget->topLevelItemCount() >= getNumberOfGCPs());
     pushSaveRef->setEnabled(treeWidget->topLevelItemCount() > 0);
 
@@ -376,6 +383,9 @@ void CCreateMapGeoTiff::slotLoadRef()
 
 void CCreateMapGeoTiff::loadGCP(const QString& filename)
 {
+
+    QString gcpproj("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs");
+
     QFile file(filename);
     file.open(QIODevice::ReadOnly);
     QString line = QString::fromUtf8(file.readLine());
@@ -383,6 +393,7 @@ void CCreateMapGeoTiff::loadGCP(const QString& filename)
     {
         QRegExp re1("^-gcp\\s(-{0,1}[0-9]+)\\s(-{0,1}[0-9]+)\\s(.*)$");
         QRegExp re2("^-a_srs\\s(.*)$");
+        QRegExp re3("^#gcpproj:\\s(.*)$");
 
         while(1)
         {
@@ -405,7 +416,11 @@ void CCreateMapGeoTiff::loadGCP(const QString& filename)
             }
             else if(re2.exactMatch(line))
             {
-                lineProjection->setText(re2.cap(1).trimmed());
+                lineMapProjection->setText(re2.cap(1).trimmed());
+            }
+            else if(re3.exactMatch(line))
+            {
+                lineGCPProjection->setText(re3.cap(1).trimmed());
             }
 
             if (file.atEnd()) break;
@@ -446,7 +461,7 @@ void CCreateMapGeoTiff::loadGCP(const QString& filename)
             }
             else if(re2.exactMatch(line))
             {
-                lineProjection->setText(re2.cap(1).trimmed());
+                lineMapProjection->setText(re2.cap(1).trimmed());
             }
 
             if (file.atEnd()) break;
@@ -482,7 +497,7 @@ void CCreateMapGeoTiff::loadTAB(const QString& filename)
         oSRS.importFromWkt(&pszTabWKT);
         oSRS.exportToProj4(&ptr);
 
-        lineProjection->setText(ptr);
+        lineMapProjection->setText(ptr);
     }
 }
 
@@ -564,15 +579,21 @@ void CCreateMapGeoTiff::saveGCP(const QString& filename)
 
     file.write(QString("#V1.0\n").toUtf8());
 
-    QString projection = lineProjection->text().trimmed();
-    if(projection.isEmpty())
+    QString gcpproj = lineGCPProjection->text().trimmed();
+    if(!gcpproj.isEmpty())
     {
-        projection = "+proj=merc +ellps=WGS84 +datum=WGS84 +no_defs";
+        file.write(QString("#gcpproj: %1\n").arg(gcpproj).toUtf8());
+    }
+
+    QString mapproj = lineMapProjection->text().trimmed();
+    if(mapproj.isEmpty())
+    {
+        mapproj = "+proj=merc +ellps=WGS84 +datum=WGS84 +no_defs";
     }
 
     QStringList args;
     args << "-a_srs";
-    args << projection;
+    args << mapproj;
     args << "\n";
     file.write(args.join(" ").toUtf8());
 
@@ -602,7 +623,7 @@ void CCreateMapGeoTiff::saveTAB(const QString& filename)
 void CCreateMapGeoTiff::slotGridTool()
 {
     CCreateMapGridTool * tool = new CCreateMapGridTool(this, parentWidget());
-    theMainWindow->setTempWidget(tool);
+    theMainWindow->setTempWidget(tool, tr("Grid Tool"));
 }
 
 
@@ -641,17 +662,20 @@ void CCreateMapGeoTiff::slotGoOn()
     bool islonlat = false;
 
     // get / store target projection
-    QString projection = lineProjection->text();
-    if(projection.isEmpty())
+    QString gcpproj = lineGCPProjection->text();
+    QString mapproj = lineMapProjection->text();
+    if(mapproj.isEmpty())
     {
-        projection = "+proj=merc +ellps=WGS84 +datum=WGS84 +no_defs";
+        mapproj = "+proj=merc +ellps=WGS84 +datum=WGS84 +no_defs";
     }
-    islonlat = projection.contains("longlat");
+    islonlat = mapproj.contains("longlat");
+
+
 
     QSettings cfg;
-    cfg.setValue("create/def.proj",projection);
+    cfg.setValue("create/mapproj",mapproj);
 
-    args << "-a_srs" << projection;
+    args << "-a_srs" << mapproj;
 
     // add gcps
     double x1, x2, y1, y2, u1, u2, v1, v2;
@@ -674,15 +698,20 @@ void CCreateMapGeoTiff::slotGoOn()
             {
                 return;
             }
+//            qDebug() << "islonlat" << lon << lat;
         }
         else
         {
-            if(!GPS_Math_Str_To_LongLat(refpt->item->text(eLonLat), lon, lat, projection))
+            if(!GPS_Math_Str_To_LongLat(refpt->item->text(eLonLat), lon, lat, gcpproj, mapproj))
             {
                 return;
             }
+
+//            qDebug() << "!islonlat" << lon << lat;
         }
 
+
+
         u1 = u2; u2 = lon;
         v1 = v2; v2 = lat;
 
@@ -881,7 +910,12 @@ void CCreateMapGeoTiff::slotClearAll()
 
 void CCreateMapGeoTiff::slotProjWizard()
 {
-    CDlgProjWizzard dlg(*lineProjection, this);
+    CDlgProjWizzard dlg(*lineMapProjection, this);
+    dlg.exec();
+}
+
+void CCreateMapGeoTiff::slotGCPProjWizard()
+{
+    CDlgProjWizzard dlg(*lineGCPProjection, this);
     dlg.exec();
-
 }
