@@ -224,7 +224,7 @@ void CCreateMapGridTool::slotOk()
         {
 
             float lon, lat;
-            if(!GPS_Math_Str_To_LongLat(pt->item->text(CCreateMapGeoTiff::eLonLat), lon, lat, lineProjection->text()))
+            if(!GPS_Math_Str_To_LongLat(pt->item->text(CCreateMapGeoTiff::eLonLat), lon, lat, "", lineProjection->text()))
             {
                 delete [] gcps;
                 return;
@@ -248,7 +248,7 @@ void CCreateMapGridTool::slotOk()
         // point 1
         QMap<quint32,CCreateMapGeoTiff::refpt_t>::iterator pt = geotifftool->refpts.begin();
 
-        if(!GPS_Math_Str_To_LongLat(pt->item->text(CCreateMapGeoTiff::eLonLat), lon, lat, lineProjection->text()))
+        if(!GPS_Math_Str_To_LongLat(pt->item->text(CCreateMapGeoTiff::eLonLat), lon, lat, "", lineProjection->text()))
         {
             delete [] gcps;
             return;
@@ -261,7 +261,7 @@ void CCreateMapGridTool::slotOk()
         // point 2
         ++pt;
 
-        if(!GPS_Math_Str_To_LongLat(pt->item->text(CCreateMapGeoTiff::eLonLat), lon, lat, lineProjection->text()))
+        if(!GPS_Math_Str_To_LongLat(pt->item->text(CCreateMapGeoTiff::eLonLat), lon, lat, "", lineProjection->text()))
         {
             delete [] gcps;
             return;
@@ -371,6 +371,7 @@ void CCreateMapGridTool::slotOk()
     if(pjWGS84) pj_free(pjWGS84);
     if(pjSrc) pj_free(pjSrc);
 
+    geotifftool->lineGCPProjection->setText("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs");
     geotifftool->comboMode->setCurrentIndex(geotifftool->comboMode->findData(CCreateMapGeoTiff::eQuadratic));
 
     theMainWindow->getCanvas()->update();
