@@ -156,7 +156,7 @@ void CDiaryDB::loadGPX(CGpx& gpx)
 }
 
 
-void CDiaryDB::saveGPX(CGpx& gpx)
+void CDiaryDB::saveGPX(CGpx& gpx, const QStringList& keys)
 {
 
     if (gpx.getExportFlag())
