@@ -56,12 +56,14 @@
 #include "CDiaryEditWidget.h"
 #include "CDiaryDB.h"
 #include "CWptDB.h"
+#include "CWptToolWidget.h"
 #include "CTrackDB.h"
 #include "CMainWindow.h"
 #include "CWpt.h"
 #include "CTrack.h"
 #include "WptIcons.h"
 #include "GeoMath.h"
+#include "IUnit.h"
 
 #include <QtGui>
 
@@ -452,12 +454,12 @@ void CDiaryEditWidget::slotDocWizard()
 
     str += tr("<p>This is an automated diary.</p>");
 
-    QString key;
-    QStringList keys;
     const QMap<QString,CWpt*>& wpts = CWptDB::self().getWpts();
-
     if(!wpts.isEmpty())
     {
+        QString pos;
+        CWptToolWidget::sortmode_e sortmode = CWptToolWidget::getSortMode(pos);
+
         str += "<h2>Waypoints</h2>";
         str += "<p>";
         str += "<table border='0' cellspacing='1' cellpadding='4'  bgcolor='#448e35'>";
@@ -467,13 +469,21 @@ void CDiaryEditWidget::slotDocWizard()
         str += tr("<th align='left'>Pos.</th>");
         str += tr("<th align='left'>Name</th>");
         str += tr("<th align='left'>Elevation</th>");
+        if(sortmode == CWptToolWidget::eSortByDistance)
+        {
+            str += tr("<th align='left'>Distance</th>");
+        }
         str += tr("<th align='left'>Comment</th>");
         str += "</tr>";
-        keys = wpts.keys();
-        keys.sort();
-        foreach(key,keys)
+
+
+        CWptDB::keys_t key;
+        QList<CWptDB::keys_t> keys = CWptDB::self().keys();
+
+        foreach(key, keys)
         {
-            CWpt * wpt = wpts[key];
+            CWpt * wpt = CWptDB::self().getWptByKey(key.key);
+
             if(wpt->sticky) continue;
 
             QString pos;
@@ -494,15 +504,24 @@ void CDiaryEditWidget::slotDocWizard()
                 str += QString("<td align='left' valign='top'>-</td>");
             }
 
+            if(sortmode == CWptToolWidget::eSortByDistance)
+            {
+                QString val, unit;
+                IUnit::self().meter2distance(key.d, val, unit);
+
+                str += QString("<td align='left' valign='top'>%1 %2</td>").arg(val).arg(unit);
+            }
+
             str += QString("<td align='left' valign='top'>%1</td>").arg(wpt->comment);
             str += "</tr>";
 
         }
+
         str += "</table>";
         str += "</p>";
     }
 
-    const QMap<QString,CTrack*>& tracks = CTrackDB::self().getTracks();
+    const QMap<QString,CTrack*>& tracks = CTrackDB::self().getTracks();       
     if(!tracks.isEmpty())
     {
         str += "<h2>Tracks</h2>";
@@ -518,11 +537,12 @@ void CDiaryEditWidget::slotDocWizard()
         str += tr("<th align='left'>Comment</th>");
         str += "</tr>";
 
-        keys = tracks.keys();
-        keys.sort();
+        CTrackDB::keys_t key;
+        QList<CTrackDB::keys_t> keys = CTrackDB::self().keys();
+
         foreach(key,keys)
         {
-            CTrack * track = tracks[key];
+            CTrack * track = tracks[key.key];
             str += "<tr bgcolor='#ffffff'>";
             str += QString("<td bgcolor='%1' style='width: 20px;'>&nbsp;&nbsp;</td>").arg(track->getColor().name());
             str += QString("<td align='left' valign='top'>%1</td>").arg(track->getStartTimestamp().toString());
