@@ -76,7 +76,7 @@ void CDlgEditMapLevel::accept()
 void CDlgEditMapLevel::slotSelectFiles()
 {
 
-    QStringList files = QFileDialog::getOpenFileNames(0, tr("Select <b>all</b> files for that level."), mapPath, "All (*.*);;GeoTiff (*.tif)", 0, QFileDialog::DontUseNativeDialog);
+    QStringList files = QFileDialog::getOpenFileNames(0, tr("Select <b>all</b> files for that level."), mapPath, "All (*.*);;GeoTiff (*.tif *.tiff)", 0, QFileDialog::DontUseNativeDialog);
     if(files.isEmpty()) return;
 
     listFiles->clear();
@@ -111,7 +111,7 @@ void CDlgEditMapLevel::slotListChanged()
 
 void CDlgEditMapLevel::slotAdd()
 {
-    QStringList files = QFileDialog::getOpenFileNames(0, tr("Select <b>all</b> files for that level."), mapPath, "All (*.*);;GeoTiff (*.tif)", 0, QFileDialog::DontUseNativeDialog);
+    QStringList files = QFileDialog::getOpenFileNames(0, tr("Select <b>all</b> files for that level."), mapPath, "All (*.*);;GeoTiff (*.tif *.tiff)", 0, QFileDialog::DontUseNativeDialog);
     if(files.isEmpty()) return;
 
     QDir dir(mapPath);
