@@ -83,16 +83,20 @@ CDlgTrackFilter::CDlgTrackFilter(CTrack &track, QWidget * parent)
     // user-tunable elements on "Modify Timestamps" tab
     connect(buttonReset1stOfMonth, SIGNAL(clicked()), this, SLOT(slotReset1stOfMonth()));
     connect(buttonResetEpoch, SIGNAL(clicked()), this, SLOT(slotResetEpoch()));
-    connect(datetimeStartTime, SIGNAL(dateTimeChanged(const QDateTime &)), this,
-        SLOT(slotDateTimeChanged(const QDateTime &)));
+    connect(datetimeStartTime, SIGNAL(dateTimeChanged(const QDateTime &)), this, SLOT(slotDateTimeChanged(const QDateTime &)));
 
     // user-tunable elements on "Reduce Dataset" tab
     connect(radioDistance, SIGNAL(clicked()), this, SLOT(slotRadioDistance()));
     connect(radioTimedelta, SIGNAL(clicked()), this, SLOT(slotRadioTimedelta()));
     connect(spinDistance, SIGNAL(valueChanged(int)), this, SLOT(slotSpinDistance(int)));
     connect(spinTimedelta, SIGNAL(valueChanged(int)), this, SLOT(slotSpinTimedelta(int)));
-    connect(comboMeterFeet, SIGNAL(currentIndexChanged(const QString &)), this,
-        SLOT(slotComboMeterFeet(const QString &)));
+    connect(comboMeterFeet, SIGNAL(currentIndexChanged(const QString &)), this, SLOT(slotComboMeterFeet(const QString &)));
+
+    connect(radioSplitChunks, SIGNAL(clicked()), this, SLOT(slotRadioSplitChunks()));
+    connect(radioSplitPoints, SIGNAL(clicked()), this, SLOT(slotRadioSplitPoints()));
+    connect(spinSplitChunks, SIGNAL(valueChanged(int)), this, SLOT(slotSplitChunks(int)));
+    connect(spinSplitPoints, SIGNAL(valueChanged(int)), this, SLOT(slotSplitPoints(int)));
+
 }
 
 
@@ -104,24 +108,109 @@ CDlgTrackFilter::~CDlgTrackFilter()
 
 void CDlgTrackFilter::accept()
 {
-    qDebug() << "Accepting track filter";
-    bool need_rebuild = false;
-    QList<CTrack::pt_t>& trkpts = track.getTrackPoints();
+    if(checkSplitTrack->isChecked())
+    {
+        splitTrack(&track);
+    }
+    else
+    {
+        modifyTimestamp(&track);
+        reduceDataset(&track);
+    }
+
+    QSettings cfg;
+    cfg.setValue("trackfilter/distance",spinDistance->value());
+    cfg.setValue("trackfilter/timedelta",spinTimedelta->value());
+
+    QDialog::accept();
+}
+
+void CDlgTrackFilter::splitTrack(CTrack * trk)
+{
+
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+
+    QList<CTrack::pt_t>& trkpts         = trk->getTrackPoints();
+    QList<CTrack::pt_t>::iterator trkpt = trkpts.begin();
     int npts = trkpts.count();
 
     QProgressDialog progress(tr("Filter track..."), tr("Abort filter"), 0, npts, this);
     progress.setWindowTitle("Filter Progress");
     progress.setWindowModality(Qt::WindowModal);
 
+    int chunk;
+    if(radioSplitChunks->isChecked())
+    {
+        int n = spinSplitChunks->value();
+        chunk = (trkpts.size() + n) / n;
+    }
+    else
+    {
+        chunk = spinSplitPoints->value();
+    }
+
+
+    int totalCnt    = 0;
+    int trkptCnt    = 0;
+    int trkCnt      = 1;
+
+    CTrack * track1 = new CTrack(&CTrackDB::self());
+    track1->setName(trk->getName() + QString("_%1").arg(trkCnt++));
+
+    while(trkpt != trkpts.end())
+    {
+
+        progress.setValue(totalCnt++);
+        qApp->processEvents(QEventLoop::AllEvents, 100);
+
+        *track1 << *trkpt;
+        if(++trkptCnt >= chunk)
+        {
+            modifyTimestamp(track1);
+            reduceDataset(track1);
+
+            CTrackDB::self().addTrack(track1, true);
+
+            trkptCnt = 0;
+            track1 = new CTrack(&CTrackDB::self());
+            track1->setName(trk->getName() + QString("_%1").arg(trkCnt++));
+        }
+
+        trkpt++;
+    }
+
+    if(trkptCnt)
+    {
+        modifyTimestamp(track1);
+        reduceDataset(track1);
+
+        CTrackDB::self().addTrack(track1, false);
+    }
+    else
+    {
+        delete track1;
+    }
+
+
+    QApplication::restoreOverrideCursor();
+
+}
+
+void CDlgTrackFilter::modifyTimestamp(CTrack * trk)
+{
     if(tabTimestamp->isEnabled() && checkModifyTimestamps->isChecked())
     {
+        QList<CTrack::pt_t>& trkpts = trk->getTrackPoints();
+        int npts = trkpts.count();
+
+        QProgressDialog progress(tr("Filter track..."), tr("Abort filter"), 0, npts, this);
+        progress.setWindowTitle("Filter Progress");
+        progress.setWindowModality(Qt::WindowModal);
+
         QList<CTrack::pt_t>::iterator trkpt   = trkpts.begin();
 
         if(trkpt->timestamp != 0x000000000 && trkpt->timestamp != 0xFFFFFFFF)
         {
-            qDebug() << "Modifying track timestamps";
-            need_rebuild = true;
-
             QDateTime t;
             if(radioLocalTime->isChecked())
             {
@@ -150,19 +239,33 @@ void CDlgTrackFilter::accept()
                 qApp->processEvents(QEventLoop::AllEvents, 100);
                 ++i;
                 if (progress.wasCanceled())
+                {
                     break;
+                }
             }
         }
+        progress.setValue(npts);
+        track.rebuild(false);
     }
+}
+
+void CDlgTrackFilter::reduceDataset(CTrack * trk)
+{
+
 
     if(checkReduceDataset->isChecked())
     {
+        QList<CTrack::pt_t>& trkpts = trk->getTrackPoints();
+        int npts = trkpts.count();
+
+        QProgressDialog progress(tr("Filter track..."), tr("Abort filter"), 0, npts, this);
+        progress.setWindowTitle("Filter Progress");
+        progress.setWindowModality(Qt::WindowModal);
+
         QList<CTrack::pt_t>::iterator trkpt   = trkpts.begin();
 
         if(radioTimedelta->isEnabled() && radioTimedelta->isChecked())
         {
-            qDebug() << "Reducing track dataset by timedelta";
-            need_rebuild = true;
 
             quint32 timedelta = spinTimedelta->value();
             quint32 lasttime = trkpt->timestamp;
@@ -193,9 +296,6 @@ void CDlgTrackFilter::accept()
         }
         else if(radioDistance->isChecked())
         {
-            qDebug() << "Reducing track dataset by distance";
-            need_rebuild = true;
-
             float min_distance = spinDistance->value();
             if(spinDistance->suffix() == "ft")
             {
@@ -236,32 +336,11 @@ void CDlgTrackFilter::accept()
 
             QApplication::restoreOverrideCursor();
         }
-    }
-
-    progress.setValue(npts);
-    if(need_rebuild)
-    {
+        progress.setValue(npts);
         track.rebuild(false);
     }
-
-    QSettings cfg;
-
-    cfg.setValue("trackfilter/distance",spinDistance->value());
-    cfg.setValue("trackfilter/timedelta",spinTimedelta->value());
-
-    QDialog::accept();
 }
 
-
-void CDlgTrackFilter::reject()
-{
-
-    qDebug() << "Rejecting track filter";
-
-    QDialog::reject();
-}
-
-
 void CDlgTrackFilter::slotReset1stOfMonth()
 {
     QDateTime t = datetimeStartTime->dateTime();
@@ -340,3 +419,31 @@ void CDlgTrackFilter::slotComboMeterFeet(const QString &text)
 {
     spinDistance->setSuffix(text);
 }
+
+void CDlgTrackFilter::slotRadioSplitChunks()
+{
+
+    checkSplitTrack->setChecked(true);
+}
+
+void CDlgTrackFilter::slotRadioSplitPoints()
+{
+
+    checkSplitTrack->setChecked(true);
+}
+
+void CDlgTrackFilter::slotSplitChunks(int)
+{
+    radioSplitChunks->setChecked(true);
+    radioSplitPoints->setChecked(false);
+
+    checkSplitTrack->setChecked(true);
+}
+
+void CDlgTrackFilter:: slotSplitPoints(int)
+{
+    radioSplitChunks->setChecked(false);
+    radioSplitPoints->setChecked(true);
+
+    checkSplitTrack->setChecked(true);
+}
