@@ -55,6 +55,7 @@ sign_info_t::sign_info_t()
 
 
 quint32 CGarminPolygon::cnt = 0;
+quint32 CGarminPolygon::maxVecSize = 0;
 
 CGarminPolygon::CGarminPolygon()
 : type(0)
@@ -97,6 +98,12 @@ quint32 CGarminPolygon::decode(qint32 iCenterLon, qint32 iCenterLat, quint32 shi
 
     const quint8 * const pStart = pData;
 
+    labels.clear();
+    u.resize(0);
+    v.resize(0);
+    u.reserve(maxVecSize);
+    v.reserve(maxVecSize);
+
     /* poly_type
 
         for polylines:
@@ -229,6 +236,16 @@ quint32 CGarminPolygon::decode(qint32 iCenterLon, qint32 iCenterLat, quint32 shi
 
     id = cnt++;
     //     qDebug() << "<<<" << id;
+
+    if(maxVecSize < u.size())
+    {
+      maxVecSize = u.size();
+    }
+    if(u.size() * 1.2 < maxVecSize)
+    {
+        u.squeeze();
+        v.squeeze();
+    }
     return bytes_total;
 }
 
@@ -249,6 +266,12 @@ quint32 CGarminPolygon::decode2(qint32 iCenterLon, qint32 iCenterLat, quint32 sh
 
     const quint8 * const pStart = pData;
 
+    labels.clear();
+    u.resize(0);
+    v.resize(0);
+    u.reserve(maxVecSize);
+    v.reserve(maxVecSize);
+
     type        = *pData++;
     subtype     = *pData++;;
 
@@ -350,6 +373,16 @@ quint32 CGarminPolygon::decode2(qint32 iCenterLon, qint32 iCenterLat, quint32 sh
     id = cnt++;
     //     qDebug() << "<<<" << id;
 
+    if(maxVecSize < u.size())
+    {
+      maxVecSize = u.size();
+    }
+    if(u.size() * 1.2 < maxVecSize)
+    {
+        u.squeeze();
+        v.squeeze();
+    }
+
     return bytes_total;
 }
 
