@@ -30,7 +30,7 @@
 #include "CGarminPolygon.h"
 #include "CGarminPoint.h"
 
-class QFile;
+class QFileExt;
 class QByteArray;
 class QPainter;
 class IMap;
@@ -174,6 +174,7 @@ class CGarminTile : public QObject
 
         */
         void loadVisibleData(bool fast, polytype_t& polygons, polytype_t& polylines, pointtype_t& points, pointtype_t& pois, unsigned level, const QRectF& viewport);
+
         /// read all polygons of a certain type in a file
         /**
             @param polygons     reference to vector to store polygons
@@ -182,6 +183,8 @@ class CGarminTile : public QObject
         */
         void loadPolygonsOfType(polytype_t& polygons, quint16 type, unsigned level);
 
+#ifdef SQL_SEARCH_GARMIN
+
         /// create database index for later element lookup
         void createIndex(QSqlDatabase& db);
         /// read a single polyline
@@ -194,12 +197,13 @@ class CGarminTile : public QObject
         void readPolyline(const QString& subfile, quint32 subdiv, quint32 offset, polytype_t& polylines);
 
         void readPoint(const QString& subfile, quint32 n, quint32 offset, pointtype_t& point);
+#endif                       //SQL_SEARCH_GARMIN
 
     private:
-        void readFile(QFile& file, quint32 offset, quint32 size, QByteArray& data);
-        void readSubfileBasics(subfile_desc_t& subfile, QFile& file);
-        void loadSubDiv(QFile& file, const subdiv_desc_t& subdiv, IGarminStrTbl * strtbl, const QByteArray& rgndata, bool fast, polytype_t& polylines, polytype_t& polygons, pointtype_t& points, pointtype_t& pois);
-        void createIndexSubDiv(QFile& file, quint32 idSubfile, const subdiv_desc_t& subdiv, IGarminStrTbl * strtbl, const QByteArray& rgndata, QSqlDatabase& db);
+        void readFile(QFileExt& file, quint32 offset, quint32 size, QByteArray& data);
+        void readSubfileBasics(subfile_desc_t& subfile, QFileExt& file);
+        void loadSubDiv(QFileExt& file, const subdiv_desc_t& subdiv, IGarminStrTbl * strtbl, const QByteArray& rgndata, bool fast, const QRectF& viewport, polytype_t& polylines, polytype_t& polygons, pointtype_t& points, pointtype_t& pois);
+        void createIndexSubDiv(QFileExt& file, quint32 idSubfile, const subdiv_desc_t& subdiv, IGarminStrTbl * strtbl, const QByteArray& rgndata, QSqlDatabase& db);
 
         // share the structures
         friend class CGarminExport;
@@ -457,6 +461,8 @@ class CGarminTile : public QObject
         QString filename;
         /// xor mask for encrypted files
         quint8 mask;
+        quint32 mask32;
+        quint64 mask64;
         /// map description string
         QString mapdesc;
         /// hold all subfile descriptors
