@@ -67,6 +67,7 @@ void CLiveLogDB::saveBackupLog()
         QFile tmp(QDir::temp().filePath("qlBackupLog"));
         tmp.open(QIODevice::ReadOnly);
         QDataStream in(&tmp);
+        in.setVersion(QDataStream::Qt_4_5);
 
         CTrack * t = new CTrack(&CTrackDB::self());
         t->setName(tr("LiveLog"));
@@ -136,6 +137,11 @@ void CLiveLogDB::clear()
 
 void CLiveLogDB::slotLiveLog(const CLiveLog& log)
 {
+    CLiveLogToolWidget * w = qobject_cast<CLiveLogToolWidget*>(toolview);
+    if(w == 0) return;
+
+    // always update the time
+    w->lblTime->setText(QDateTime::fromTime_t(log.timestamp).toString());
 
     if(m_log.lat == log.lat && m_log.lon == log.lon && m_log.fix == log.fix) return;
 
@@ -143,9 +149,6 @@ void CLiveLogDB::slotLiveLog(const CLiveLog& log)
 
     *backup << log;
 
-    CLiveLogToolWidget * w = qobject_cast<CLiveLogToolWidget*>(toolview);
-    if(w == 0) return;
-
     float speed_km_h = log.velocity * 3.6;
     float heading = log.heading;
     if( speed_km_h < 0.3 )
@@ -183,7 +186,6 @@ void CLiveLogDB::slotLiveLog(const CLiveLog& log)
         {
             w->lblHeading->setText(tr("%1\260 T").arg((int)(heading + 0.5),3,'f',0,'0'));
         }
-        w->lblTime->setText(QDateTime::fromTime_t(log.timestamp).toString());
 
         simplelog_t slog;
         slog.timestamp  = log.timestamp;
@@ -201,9 +203,9 @@ void CLiveLogDB::slotLiveLog(const CLiveLog& log)
         if(m_lockToCenter)
         {
             QSize size  = map.getSize();
-            int   dx    = size.width()  / 4;
-            int   dy    = size.height() / 4;
-            QRect area  = QRect(dx, dy, 2*dx, 2*dy);
+            int   dx    = size.width()  / 6;
+            int   dy    = size.height() / 6;
+            QRect area  = QRect(2*dx, 2*dy, 2*dx, 2*dy);
             if(!area.contains(u,v))
             {
                 map.move(QPoint(u,v), area.center());
