@@ -44,6 +44,7 @@
 #include "WptIcons.h"
 #include "CAppOpts.h"
 #include "CMap3D.h"
+#include "CDlgExport.h"
 
 #include <QtGui>
 #ifdef WIN32
@@ -90,6 +91,13 @@ CMainWindow::CMainWindow()
     megaMenu = new CMegaMenu(canvas);
     leftSplitter->addWidget(megaMenu);
 
+    tmpTabWidget = new QTabWidget(this);
+    tmpTabWidget->setTabsClosable(true);
+    tmpTabWidget->setTabPosition(QTabWidget::South);;
+    tmpTabWidget->hide();
+    rightSplitter->addWidget(tmpTabWidget);
+    connect(tmpTabWidget, SIGNAL(tabCloseRequested(int)), this, SLOT(slotTabCloseRequest(int)));
+
     connect(leftSplitter, SIGNAL(splitterMoved(int, int)), megaMenu, SLOT(slotSplitterMoved(int, int)));
 
     CActions *actions = actionGroupProvider->getActions();
@@ -156,9 +164,7 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::TrackMenu, "aSelTrack");
     actionGroupProvider->addAction(CMenus::TrackMenu, "aUploadTrack");
     actionGroupProvider->addAction(CMenus::TrackMenu, "aDownloadTrack");
-    actionGroupProvider->addAction(CMenus::TrackMenu, "aCopyToClipboard");
-    actionGroupProvider->addAction(CMenus::TrackMenu, "aPasteFromClipboard");
-    actionGroupProvider->addAction(CMenus::TrackMenu, "aDeleteTrackSelection");
+    actionGroupProvider->addAction(CMenus::TrackMenu, "aTrackPurgeSelection");
 
     actionGroupProvider->addAction(CMenus::LiveLogMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::LiveLogMenu, "aMoveArea");
@@ -174,7 +180,14 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aCenterMap");
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aText");
     actionGroupProvider->addAction(CMenus::OverlayMenu, "aTextBox");
-    actionGroupProvider->addAction(CMenus::OverlayMenu, "aDistance");
+    actionGroupProvider->addAction(CMenus::OverlayMenu, "aSwitchToOverlayDistance");
+
+    actionGroupProvider->addAction(CMenus::OverlayDistanceMenu, "aBackToOverlay");
+    actionGroupProvider->addAction(CMenus::OverlayDistanceMenu, "aMoveArea");
+    actionGroupProvider->addAction(CMenus::OverlayDistanceMenu, "aZoomArea");
+    actionGroupProvider->addAction(CMenus::OverlayDistanceMenu, "aCenterMap");
+    actionGroupProvider->addAction(CMenus::OverlayDistanceMenu, "aCombineDistOvl");
+    actionGroupProvider->addAction(CMenus::OverlayDistanceMenu, "aDistance");
 
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aMoveArea");
@@ -190,6 +203,8 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::RouteMenu, "aUploadRoute");
     actionGroupProvider->addAction(CMenus::RouteMenu, "aDownloadRoute");
 
+
+
     connect(actionGroupProvider, SIGNAL(stateChanged()),megaMenu , SLOT(switchState()));
 
     switchState();
@@ -393,7 +408,7 @@ void CMainWindow::dropEvent(QDropEvent *event)
 
     foreach(url, urls)
     {
-        QString filename = url.path();
+        QString filename = url.toLocalFile();
         QString filter;
         loadData(filename, filter);
     }
@@ -441,12 +456,6 @@ void CMainWindow::clear()
 }
 
 
-void CMainWindow::setTempWidget(QWidget * w)
-{
-    rightSplitter->addWidget(w);
-}
-
-
 void CMainWindow::setPositionInfo(const QString& info)
 {
     statusCoord->setText(info);
@@ -501,6 +510,11 @@ void CMainWindow::setupMenuBar()
     menu->addAction(QIcon(":/icons/iconExit16x16.png"),tr_nomac("Exit"),this,SLOT(close()));
     menuBar()->addMenu(menu);
 
+    menu = new QMenu(this);
+    actionGroupProvider->addActionsToMenu(menu,CMenus::MenuBarMenu,CMenus::EditMenu);
+    menu->setTitle(tr("&Edit"));
+    menuBar()->addMenu(menu);
+
     menu = new QMenu(this);
     actionGroupProvider->addActionsToMenu(menu,CMenus::MenuBarMenu,CMenus::MapMenu);
     menu->setTitle(tr("&Map"));
@@ -619,7 +633,11 @@ void CMainWindow::slotConfig()
 void CMainWindow::slotLoadData()
 {
 
-    bool haveGPSBabel = QProcess::execute(GPSBABEL " -V") == 0;
+    QProcess proc1;
+    proc1.start(GPSBABEL " -V");
+    proc1.waitForFinished();
+    bool haveGPSBabel = proc1.exitCode() == 0;
+
     QString formats;
     if(haveGPSBabel)
     {
@@ -674,7 +692,11 @@ void CMainWindow::slotLoadData()
 
 void CMainWindow::slotAddData()
 {
-    bool haveGPSBabel = QProcess::execute(GPSBABEL " -V") == 0;
+    QProcess proc1;
+    proc1.start(GPSBABEL " -V");
+    proc1.waitForFinished();
+    bool haveGPSBabel = proc1.exitCode() == 0;
+
     QString formats;
     if(haveGPSBabel)
     {
@@ -970,14 +992,26 @@ void CMainWindow::saveData(QString& fn, const QString& filter, bool exportFlag)
         }
         else if(ext == "GPX")
         {
+            QStringList keysWpt, keysTrk, keysRte;
+
+            if(exportFlag)
+            {
+                CDlgExport dlg(0, &keysWpt, &keysTrk, &keysRte);
+
+                if( dlg.exec() == QDialog::Rejected)
+                {
+                    return;
+                }
+            }
+
             CGpx gpx(this, exportFlag);
-            CMapDB::self().saveGPX(gpx);
-            CWptDB::self().saveGPX(gpx);
-            CTrackDB::self().saveGPX(gpx);
-            CRouteDB::self().saveGPX(gpx);
+            CMapDB::self().saveGPX(gpx, QStringList());
+            CWptDB::self().saveGPX(gpx, keysWpt);
+            CTrackDB::self().saveGPX(gpx, keysTrk);
+            CRouteDB::self().saveGPX(gpx, keysRte);
             gpx.makeExtensions();
-            CDiaryDB::self().saveGPX(gpx);
-            COverlayDB::self().saveGPX(gpx);
+            CDiaryDB::self().saveGPX(gpx, QStringList());
+            COverlayDB::self().saveGPX(gpx, QStringList());
             gpx.save(filename);
         }
 
@@ -1253,3 +1287,30 @@ void CMainWindow::addRecent(const QString& filename)
     }
 
 }
+
+void CMainWindow::setTempWidget(QWidget * w, const QString& label)
+{
+//    rightSplitter->addWidget(w);
+    tmpTabWidget->addTab(w, label);
+    tmpTabWidget->show();
+    tmpTabWidget->setCurrentWidget(w);
+
+    connect(w, SIGNAL(destroyed(QObject*)), this, SLOT(slotItemDestroyed(QObject*)));
+}
+
+void CMainWindow::slotItemDestroyed(QObject *)
+{
+    if(tmpTabWidget->count() < 2)
+    {
+        tmpTabWidget->hide();
+    }
+}
+
+void CMainWindow::slotTabCloseRequest(int i)
+{
+    QWidget * w = tmpTabWidget->widget(i);
+    if(w)
+    {
+        w->deleteLater();
+    }
+}
