@@ -75,12 +75,12 @@ class CMapDB : public IDB
         void draw(QPainter& p, const QRect& rect, bool& needsRedraw);
 
         void loadGPX(CGpx& gpx);
-        void saveGPX(CGpx& gpx);
+        void saveGPX(CGpx& gpx, const QStringList& keys);
 
         void loadQLB(CQlb& qlb);
         void saveQLB(CQlb& qlb);
 
-        void upload();
+        void upload(const QStringList& keys);
         void download();
 
         /// remove all selected map areas
