@@ -139,6 +139,7 @@ void CMapDEM::convertM2Pt(double& u, double& v)
 
 void CMapDEM::move(const QPoint& old, const QPoint& next)
 {
+    setAngleNorth();
 }
 
 
@@ -167,9 +168,11 @@ void CMapDEM::dimensions(double& lon1, double& lat1, double& lon2, double& lat2)
 }
 
 
-qint16 *CMapDEM::getOrigRegion(XY &topLeft, XY &bottomRight, int& w, int& h)
+bool CMapDEM::getOrigRegion(QVector<qint16>& data,XY &topLeft, XY &bottomRight, int& w, int& h)
 {
-    if(pjsrc == 0) return NULL;
+    //memset(data, 0, sizeof(qint16) * h * w);
+    data.fill(0);
+    if(pjsrc == 0) return false;
 
     // 1. convert top left and bottom right point into the projection system used by the DEM data
     pj_transform(pjtar, pjsrc, 1, 0, &topLeft.u, &topLeft.v, 0);
@@ -192,9 +195,9 @@ qint16 *CMapDEM::getOrigRegion(XY &topLeft, XY &bottomRight, int& w, int& h)
     int yoff2 = ceil(yoff2_f);   //qDebug() << "yoff2:" << yoff2 << yoff2_f;
 
     // 6. get width and height to read from file
-    quint32 w1 = xoff2 - xoff1 + 1;
+    qint32 w1 = xoff2 - xoff1 + 1;
                                  //qDebug() << "w1:" << w1 << "h1:" << h1;
-    quint32 h1 = yoff2 - yoff1 + 1;
+    qint32 h1 = yoff2 - yoff1 + 1;
 
     topLeft.u = xoff1 * xscale + xref1;
     topLeft.v = yoff1 * yscale + yref1;
@@ -204,34 +207,32 @@ qint16 *CMapDEM::getOrigRegion(XY &topLeft, XY &bottomRight, int& w, int& h)
     pj_transform(pjsrc, pjtar, 1, 0, &bottomRight.u, &bottomRight.v, 0);
 
     // memory sanity check
-    if(double(w1) * double(h1) > pow(2.0f,31)) return NULL;
+    if(double(w1) * double(h1) > pow(2.0f,31)) return false;
+
     if (w1 < w)
+    {
         w = w1;
+    }
     if (h1 < h)
+    {
         h = h1;
+    }
+
+    Q_ASSERT(w1 <= w);
+    Q_ASSERT(h1 <= h);
 
     // 7. read DEM data from file
-    qDebug() << w << h;
-    qint16 * pData = new qint16[w*h];
-
-    CPLErr err = dataset->RasterIO(GF_Read, xoff1, yoff1, w1, h1, pData, w, h, GDT_Int16, 1, 0, 0, 0, 0);
-    if(err == CE_Failure)
-    {
-        qDebug() << "failure" << endl;
-        //FIXME add handle error
-        delete [] pData;
-        return NULL;
-    }
-    return pData;
+    CPLErr err = dataset->RasterIO(GF_Read, xoff1, yoff1, w1, h1, data.data(), w, h, GDT_Int16, 1, 0, 0, 0, 0);
+    return (err != CE_Failure);
 }
 
 
-void CMapDEM::getRegion(float *data, XY topLeft, XY bottomRight, int w, int h)
+bool CMapDEM::getRegion(QVector<float>& data, XY topLeft, XY bottomRight, int w, int h)
 {
     //     qDebug() << topLeft.u << topLeft.v << bottomRight.u << bottomRight.v << w << h;
-    memset(data, 0, sizeof(float) * h * w);
+    data.fill(0.0);
 
-    if(pjsrc == 0) return;
+    if(pjsrc == 0) return false;
 
     // 1. convert top left and bottom right point into the projection system used by the DEM data
     pj_transform(pjtar, pjsrc, 1, 0, &topLeft.u, &topLeft.v, 0);
@@ -259,7 +260,7 @@ void CMapDEM::getRegion(float *data, XY topLeft, XY bottomRight, int w, int h)
     quint32 h1 = yoff2 - yoff1 + 1;
 
     // memory sanity check
-    if(double(w1) * double(h1) > pow(2.0f,31)) return;
+    if(double(w1) * double(h1) > pow(2.0f,31)) return false;
 
     // 7. read DEM data from file
     QVector<qint16> _tmp_(w1*h1);
@@ -269,8 +270,8 @@ void CMapDEM::getRegion(float *data, XY topLeft, XY bottomRight, int w, int h)
     if(err == CE_Failure)
     {
         qDebug() << "failure" << endl;
-        //FIXME add handle error
-        return;
+
+        return false;
     }
 
     double xstep = (xoff2_f  - xoff1_f) / (w - 1);
@@ -310,6 +311,8 @@ void CMapDEM::getRegion(float *data, XY topLeft, XY bottomRight, int w, int h)
 
         }
     }
+
+    return true;
 }
 
 
