@@ -1065,7 +1065,7 @@ bool CMapTDB::processPrimaryMapData()
 
     qDebug() << "name:\t\t" << name;
     qDebug() << "basemap:\t" << basemap;
-    qDebug() << "dimensions:\t" << "N" << north << "E" << east << "S" << south << "W" << west;
+    qDebug() << "dimensions:\t" << "N" << (north*RAD_TO_DEG) << "E" << (east*RAD_TO_DEG) << "S" << (south*RAD_TO_DEG) << "W" << (west*RAD_TO_DEG);
 
     const QMap<QString,CGarminTile::subfile_desc_t>& subfiles            = baseimg->getSubFiles();
     QMap<QString,CGarminTile::subfile_desc_t>::const_iterator subfile    = subfiles.begin();
@@ -2243,6 +2243,7 @@ void CMapTDB::drawPoints(QPainter& p, pointtype_t& pts, QVector<QRect>& rectPois
 
         if(isCluttered(rectPois, QRect(pt->lon, pt->lat,16,16)))
         {
+            p.drawPixmap(pt->lon - 4, pt->lat - 4, QPixmap(":/icons/small_bullet_blue.png"));
             ++pt;
             continue;
         }
@@ -2299,6 +2300,7 @@ void CMapTDB::drawPois(QPainter& p, pointtype_t& pts, QVector<QRect>& rectPois)
 
         if(isCluttered(rectPois, QRect(pt->lon, pt->lat,16,16)))
         {
+            p.drawPixmap(pt->lon - 4, pt->lat - 4, QPixmap(":/icons/small_bullet_blue.png"));
             ++pt;
             continue;
         }
@@ -2447,6 +2449,8 @@ void CMapTDB::getInfoPolylines(QPoint& pt, QMultiMap<QString, QString>& dict)
 
     shortest = 50;
 
+    bool found = false;
+
     polytype_t::const_iterator line = polylines.begin();
     while(line != polylines.end())
     {
@@ -2519,12 +2523,18 @@ void CMapTDB::getInfoPolylines(QPoint& pt, QMultiMap<QString, QString>& dict)
                 resPt.setX(x);
                 resPt.setY(y);
                 shortest = distance;
+                found = true;
             }
 
         }
         ++line;
     }
 
+    if(!found)
+    {
+        return;
+    }
+
     if(selectedLanguage != -1)
     {
         key =  polylineProperties[type].strings[selectedLanguage];
@@ -2536,12 +2546,106 @@ void CMapTDB::getInfoPolylines(QPoint& pt, QMultiMap<QString, QString>& dict)
     }
     else
     {
-        dict.insert(tr("Unknown") + QString("(%1)").arg(type,2,16,QChar('0')),value);
+        if(polylineProperties[type].strings.isEmpty())
+        {
+            dict.insert(tr("Unknown") + QString("(%1)").arg(type,2,16,QChar('0')),value);
+        }
+        else
+        {
+            dict.insert(polylineProperties[type].strings[0] + QString("(%1)").arg(type,2,16,QChar('0')),value);
+        }
     }
 
     pt = resPt.toPoint();
 }
 
+void CMapTDB::getClosePolyline(QPoint& pt, qint32 threshold, QPolygon& polyline)
+{
+    QPoint res;
+    int i = 0;                   // index into poly line
+    int len;                     // number of points in line
+    XY p1, p2;                   // the two points of the polyline close to pt
+    double dx,dy;                // delta x and y defined by p1 and p2
+    double d_p1_p2;              // distance between p1 and p2
+    double u;                    // ratio u the tangent point will divide d_p1_p2
+    double x,y;                  // coord. (x,y) of the point on line defined by [p1,p2] close to pt
+    double distance;             // the distance to the polyline
+    quint32 th = threshold;
+
+    polyline.clear();
+
+    const CGarminPolygon * pLine = 0;
+
+    polytype_t::const_iterator line = polylines.begin();
+    while(line != polylines.end())
+    {
+        len = line->u.count();
+        // need at least 2 points
+        if(len < 2)
+        {
+            ++line;
+            continue;
+        }
+
+        // see http://local.wasp.uwa.edu.au/~pbourke/geometry/pointline/
+        for(i=1; i<len; ++i)
+        {
+            p1.u = line->u[i-1];
+            p1.v = line->v[i-1];
+            p2.u = line->u[i];
+            p2.v = line->v[i];
+
+            dx = p2.u - p1.u;
+            dy = p2.v - p1.v;
+
+            d_p1_p2 = sqrt(dx * dx + dy * dy);
+
+            u = ((pt.x() - p1.u) * dx + (pt.y() - p1.v) * dy) / (d_p1_p2 * d_p1_p2);
+
+            if(u < 0.0 || u > 1.0) continue;
+
+            x = p1.u + u * dx;
+            y = p1.v + u * dy;
+
+            distance = sqrt((x - pt.x())*(x - pt.x()) + (y - pt.y())*(y - pt.y()));
+
+            if(distance < threshold)
+            {
+                switch(line->type)
+                {
+                    case 0x23: // "Minor depht contour"
+                    case 0x20: // "Minor land contour"
+                    case 0x24: // "Intermediate depth contour",
+                    case 0x21: // "Intermediate land contour",
+                    case 0x25: // "Major depth contour",
+                    case 0x22: // "Major land contour",
+                       break;
+
+                    default:
+                       res.setX(x);
+                       res.setY(y);
+
+                       pLine = &(*line);
+                       threshold = distance;
+                }
+            }
+        }
+        ++line;
+    }
+
+    if(pLine)
+    {
+        const int size = pLine->u.size();
+        for(i = 0; i < size; i++)
+        {
+            polyline << QPoint(pLine->u[i], pLine->v[i]);
+        }
+
+//        pt = res;
+    }
+
+}
+
 
 void CMapTDB::getInfoPolygons(const QPoint& pt, QMultiMap<QString, QString>& dict)
 {
