@@ -62,9 +62,9 @@ CMapToolWidget::CMapToolWidget(QTabWidget * parent)
     connect(pushExportMap, SIGNAL(clicked()), this, SLOT(slotExportMap()));
 
     tabWidget->setTabIcon(0, QIcon(":/icons/iconRaster16x16"));
-    tabWidget->setTabText(0,"");
+    tabWidget->setTabText(0,tr("Raster"));
     tabWidget->setTabIcon(1, QIcon(":/icons/iconVector16x16"));
-    tabWidget->setTabText(1,"");
+    tabWidget->setTabText(1,tr("Vector"));
 
 }
 
@@ -297,7 +297,6 @@ void CMapToolWidget::slotDeleteKnownMap()
                 wasSelected = true;
             }
             keys << item->data(eName, Qt::UserRole).toString();
-            delete item;
         }
         CMapDB::self().delKnownMap(keys);
     }
@@ -317,7 +316,6 @@ void CMapToolWidget::slotDeleteSelectedMap()
     foreach(item,items)
     {
         keys << item->data(Qt::UserRole).toString();
-        delete item;
     }
     CMapDB::self().delSelectedMap(keys);
 
@@ -357,9 +355,21 @@ void CMapToolWidget::slotExportMap()
     const IMapSelection * ms = selectedMaps[key];
     if(ms->type == IMapSelection::eRaster)
     {
-        bool haveGDALWarp       = QProcess::execute(GDALWARP " --version") == 0;
-        bool haveGDALTranslate  = QProcess::execute(GDALTRANSLATE " --version") == 0;
+        QProcess proc1;
+        proc1.start(GDALWARP " --version");
+        proc1.waitForFinished();
+        qDebug() << proc1.exitCode() << proc1.error() << proc1.errorString();
+        bool haveGDALWarp = proc1.exitCode() == 0;
+
+        proc1.start(GDALTRANSLATE " --version");
+        proc1.waitForFinished();
+        qDebug() << proc1.exitCode() << proc1.error() << proc1.errorString();
+        bool haveGDALTranslate = proc1.exitCode() == 0;
+
         bool haveGDAL = haveGDALWarp && haveGDALTranslate;
+
+        qDebug() << haveGDALWarp << haveGDALTranslate << haveGDAL;
+
         if(!haveGDAL)
         {
             QMessageBox::critical(0,tr("Error export maps..."), tr("You need to have the GDAL toolchain installed in your path."), QMessageBox::Abort, QMessageBox::Abort);
