@@ -27,7 +27,7 @@
 #include "CTrackToolWidget.h"
 
 #include <QtGui>
-#include "CUndoStack.h"
+#include "CUndoStackView.h"
 #include "CMapUndoCommandMove.h"
 
 CMouseMoveMap::CMouseMoveMap(CCanvas * parent)
@@ -51,7 +51,7 @@ void CMouseMoveMap::mouseMoveEvent(QMouseEvent * e)
     if(moveMap)
     {
         //CMapDB::self().getMap().move(oldPoint, e->pos());
-        CUndoStack::getInstance()->push(new CMapUndoCommandMove(&CMapDB::self().getMap(),oldPoint, e->pos()));
+        CUndoStackView::getInstance()->push(new CMapUndoCommandMove(&CMapDB::self().getMap(),oldPoint, e->pos()));
         oldPoint = e->pos();
         canvas->update();
     }
@@ -85,11 +85,13 @@ void CMouseMoveMap::mousePressEvent(QMouseEvent * e)
         }
         else
         {
-            CUndoStack::getInstance()->beginMacro(tr("Move map"));
+            CUndoStackView::getInstance()->beginMacro(tr("Move map"));
             cursor = QCursor(QPixmap(":/cursors/cursorMove"));
             QApplication::setOverrideCursor(cursor);
             moveMap     = true;
             oldPoint    = e->pos();
+
+            CMapDB::self().getMap().fastDrawOn();
         }
     }
     else if(e->button() == Qt::RightButton)
@@ -103,8 +105,10 @@ void CMouseMoveMap::mouseReleaseEvent(QMouseEvent * e)
 {
     if(moveMap && (e->button() == Qt::LeftButton))
     {
-        CUndoStack::getInstance()->endMacro();
+        CUndoStackView::getInstance()->endMacro();
         moveMap = false;
+        CMapDB::self().getMap().fastDrawOff();
+
         cursor = QCursor(QPixmap(":/cursors/cursorMoveMap"),0,0);
         QApplication::restoreOverrideCursor();
         canvas->update();
@@ -144,7 +148,8 @@ void CMouseMoveMap::contextMenu(QMenu& menu)
     if(selTrkPt)
     {
         menu.addSeparator();
-        menu.addAction(QPixmap(":/icons/iconClipboard16x16.png"),tr("Copy Pos. Trackpoint"),this,SLOT(slotCopyPositionTrack()));
+        menu.addAction(QPixmap(":/icons/iconGoogleMaps16x16.png"),tr("Open Pos. with Google Maps"),this,SLOT(slotOpenGoogleMaps())); //TODO: Google Maps right click
+                menu.addAction(QPixmap(":/icons/iconClipboard16x16.png"),tr("Copy Pos. Trackpoint"),this,SLOT(slotCopyPositionTrack()));
         menu.addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit Track ..."),this,SLOT(slotEditTrack()));
     }
 }
@@ -237,3 +242,20 @@ void CMouseMoveMap::slotEditTrack()
         track->setPointOfFocus(selTrkPt->idx);
     }
 }
+void CMouseMoveMap::slotOpenGoogleMaps()	//TODO: Open Google Maps
+{
+        QString position;
+    GPS_Math_Deg_To_Str(selTrkPt->lon, selTrkPt->lat, position);
+
+
+        QDateTime utime = QDateTime::fromTime_t(selTrkPt->timestamp);
+    utime.setTimeSpec(Qt::LocalTime);
+    QString time = utime.toString();
+
+/*
+        QMessageBox msgBox;
+        msgBox.setText(position);
+        msgBox.exec();
+*/
+        QDesktopServices::openUrl(QUrl("http://maps.google.com/maps?t=h&z=18&om=1&q="+position+"("+time+")", QUrl::TolerantMode));
+}
