@@ -22,14 +22,23 @@
 #include <QtGui>
 #include <QtNetwork/QHttp>
 
+#ifndef Q_OS_WIN32
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <pwd.h>
+#include <unistd.h>
+#endif
+
 #ifndef M_PI
 # define M_PI   3.14159265358979323846
 #endif
 
+QString COsmTilesHash::cacheFolder;
+
 class COsmTilesHashCacheCleanup: public QThread
 {
     public:
-        COsmTilesHashCacheCleanup(QObject *p=0) : QThread(p)
+        COsmTilesHashCacheCleanup(QObject * p) : QThread(p)
         {
             QSettings cfg;
 
@@ -39,13 +48,16 @@ class COsmTilesHashCacheCleanup: public QThread
             start(QThread::IdlePriority);
         };
 
+        virtual ~COsmTilesHashCacheCleanup()
+        {
+            //            qDebug() << "~COsmTilesHashCacheCleanup()";
+        }
+
         void run()
         {
-            QString tempDir = QDir::tempPath() + "/qlandkarteqt/cache/";
-
             qint32 totalSize = 0;
             QFileInfoList fileList;
-            QDirIterator it(tempDir, QStringList("*.png"), QDir::Files | QDir::Writable, QDirIterator::Subdirectories);
+            QDirIterator it(COsmTilesHash::getCacheFolder(), QStringList("*.png"), QDir::Files | QDir::Writable, QDirIterator::Subdirectories);
             while (it.hasNext())
             {
                 it.next();
@@ -76,13 +88,31 @@ class COsmTilesHashCacheCleanup: public QThread
 
 COsmTilesHash::COsmTilesHash(QString tileUrl)
 {
-    qDebug() << "cccccccccccc" << tileUrl;
+    if (cacheFolder.isEmpty())
+    {
+#ifndef Q_OS_WIN32
+        const char *envCache = getenv("QLGT_CACHE");
+
+        if (envCache)
+        {
+            cacheFolder = envCache;
+        }
+        else
+        {
+            struct passwd * userInfo = getpwuid(getuid());
+            cacheFolder = QDir::tempPath() + "/qlandkarteqt-" + userInfo->pw_name + "/cache/";
+        }
+#else
+        cacheFolder = QDir::tempPath() + "/qlandkarteqt/cache/";
+#endif
+        qDebug() << "using OSM tile cache folder" << cacheFolder;
+    }
+
     int index = tileUrl.indexOf('/');
     tileServer = tileUrl.left(index);
 
     tileUrlPart = tileUrl.right(tileUrl.size()-index);
-    ttileUrlPart = QString(tileUrlPart).replace('%','p');
-    COsmTilesHashCacheCleanup *cleanup = new COsmTilesHashCacheCleanup();
+    COsmTilesHashCacheCleanup *cleanup = new COsmTilesHashCacheCleanup(this);
 
     getid = -1;
     requestInProgress =false;
@@ -174,8 +204,9 @@ void COsmTilesHash::getImage(int osm_zoom, int osm_x, int osm_y, QPoint point)
     // * Each zoom level is a directory, each column is a subdirectory, and each tile in that column is a file
     // * Filename(url) format is /zoom/x/y.png
     QString osmUrlPart = QString(tileUrlPart).arg(osm_zoom).arg(osm_x).arg(osm_y);
-    QString osmFilePath = QString("%1/qlandkarteqt/cache/%2/%3/%4").arg(QDir::tempPath()).arg(tileServer).arg(ttileUrlPart).arg(osmUrlPart);
-    //     qDebug() << osmFilePath;
+    QString osmFilePath = QString("%1/%2/%3").arg(cacheFolder).arg(tileServer).arg(osmUrlPart);
+    //    qDebug() << osmUrlPart;
+    //    qDebug() << osmFilePath;
     bool needHttpAction = true;
     bool outOfDate = false;
     if (tiles.contains(osmUrlPart))
@@ -254,13 +285,21 @@ void COsmTilesHash::slotRequestFinished(int id, bool error)
     }
     QString osmUrlPart = osmUrlPartHash.value(id);
 
-    QString filePath = QString("%1/qlandkarteqt/cache/%2/%3/%4").arg(QDir::tempPath()).arg(tileServer).arg(ttileUrlPart).arg(osmUrlPart);
+    QString filePath = QString("%1/%2/%3").arg(cacheFolder).arg(tileServer).arg(osmUrlPart);
 
     //qDebug() << filePath;
     QFileInfo fi(filePath);
 
     if( ! (fi.dir().exists()) )
+    {
+#ifndef Q_OS_WIN32
+        mode_t mask = umask(S_IRWXG | S_IRWXO);
+#endif
         QDir().mkpath(fi.dir().path());
+#ifndef Q_OS_WIN32
+        umask(mask);
+#endif
+    }
 
     QFile f(filePath);
     if (f.open(QIODevice::WriteOnly))
