@@ -22,8 +22,12 @@
 #include "COverlayText.h"
 #include "COverlayTextBox.h"
 #include "COverlayDistance.h"
+#include "COverlayDistanceEditWidget.h"
+#include "CMainWindow.h"
+#include "CCanvas.h"
 #include "CQlb.h"
 #include "CGpx.h"
+#include "CDlgCombineDistOvl.h"
 
 #include <QtGui>
 #include <projects.h>
@@ -35,6 +39,7 @@ COverlayDB * COverlayDB::m_self = 0;
 
 COverlayDB::COverlayDB(QTabWidget * tb, QObject * parent)
 : IDB(tb,parent)
+, addOverlaysAsDuplicate(false)
 {
     m_self      = this;
     toolview    = new COverlayToolWidget(tb);
@@ -155,7 +160,8 @@ void COverlayDB::loadGPX(CGpx& gpx)
                 {
                     QString name;
                     QString comment;
-                    QList<XY> points;
+                    double speed = 0.0;
+                    QList<COverlayDistance::pt_t> points;
                     QDomNodeList list;
                     QDomNode node;
 
@@ -172,16 +178,24 @@ void COverlayDB::loadGPX(CGpx& gpx)
                         comment = node.toElement().text();
                     }
 
+                    list = element.elementsByTagName("speed");
+                    if(list.count() == 1)
+                    {
+                        node = list.item(0);
+                        speed = node.toElement().text().toDouble();
+                    }
+
                     list = element.elementsByTagName("point");
                     for(int i = 0; i < list.size(); ++i)
                     {
-                        XY pt;
-                        pt.u = list.item(i).toElement().attribute("lon", 0).toDouble() * DEG_TO_RAD;
-                        pt.v = list.item(i).toElement().attribute("lat", 0).toDouble() * DEG_TO_RAD;
+                        COverlayDistance::pt_t pt;
+                        pt.u    = list.item(i).toElement().attribute("lon", 0).toDouble() * DEG_TO_RAD;
+                        pt.v    = list.item(i).toElement().attribute("lat", 0).toDouble() * DEG_TO_RAD;
+                        pt.idx  = i;
                         points << pt;
                     }
 
-                    addDistance(name, comment, points);
+                    addDistance(name, comment, speed, points);
                 }
 
             }
@@ -192,7 +206,7 @@ void COverlayDB::loadGPX(CGpx& gpx)
 }
 
 
-void COverlayDB::saveGPX(CGpx& gpx)
+void COverlayDB::saveGPX(CGpx& gpx, const QStringList& keys)
 {
     if (gpx.getExportFlag())
     {
@@ -268,6 +282,10 @@ void COverlayDB::saveGPX(CGpx& gpx)
             elem.appendChild(comment);
             comment.appendChild(gpx.createTextNode(ovl->comment));
 
+            QDomElement speed = gpx.createElement("ql:speed");
+            elem.appendChild(speed);
+            speed.appendChild(gpx.createTextNode(QString("%1").arg(ovl->speed)));
+
             XY pt;
             foreach(pt, ovl->points)
             {
@@ -297,6 +315,7 @@ void COverlayDB::loadQLB(CQlb& qlb)
 }
 
 
+
 void COverlayDB::saveQLB(CQlb& qlb)
 {
     IOverlay * overlay;
@@ -326,10 +345,14 @@ void COverlayDB::delOverlays(const QStringList& keys)
 }
 
 
-COverlayText * COverlayDB::addText(const QString& text, const QRect& rect)
+COverlayText * COverlayDB::addText(const QString& text, const QRect& rect, const QString& key)
 {
     IOverlay * overlay = new COverlayText(text, rect, this);
-    overlays[overlay->key] = overlay;
+    if(!key.isEmpty() && !addOverlaysAsDuplicate)
+    {
+        overlay->_key_ = key;
+    }
+    overlays[overlay->key()] = overlay;
 
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigChanged()));
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigModified()));
@@ -341,10 +364,14 @@ COverlayText * COverlayDB::addText(const QString& text, const QRect& rect)
 }
 
 
-COverlayTextBox * COverlayDB::addTextBox(const QString& text, double lon, double lat, const QPoint& anchor, const QRect& rect)
+COverlayTextBox * COverlayDB::addTextBox(const QString& text, double lon, double lat, const QPoint& anchor, const QRect& rect, const QString& key)
 {
     IOverlay * overlay = new COverlayTextBox(text, lon, lat, anchor, rect, this);
-    overlays[overlay->key] = overlay;
+    if(!key.isEmpty() && !addOverlaysAsDuplicate)
+    {
+        overlay->_key_ = key;
+    }
+    overlays[overlay->key()] = overlay;
 
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigChanged()));
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigModified()));
@@ -356,10 +383,14 @@ COverlayTextBox * COverlayDB::addTextBox(const QString& text, double lon, double
 }
 
 
-COverlayDistance * COverlayDB::addDistance(const QString& name, const QString& comment, const QList<XY>& pts)
+COverlayDistance * COverlayDB::addDistance(const QString& name, const QString& comment, double speed, const QList<COverlayDistance::pt_t>& pts, const QString& key)
 {
-    IOverlay * overlay = new COverlayDistance(name, comment, pts, this);
-    overlays[overlay->key] = overlay;
+    IOverlay * overlay = new COverlayDistance(name, comment, speed, pts, this);
+    if(!key.isEmpty() && !addOverlaysAsDuplicate)
+    {
+        overlay->_key_ = key;
+    }
+    overlays[overlay->key()] = overlay;
 
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigChanged()));
     connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigModified()));
@@ -376,3 +407,124 @@ void COverlayDB::customMenu(const QString& key, QMenu& menu)
     if(!overlays.contains(key)) return;
     overlays[key]->customMenu(menu);
 }
+
+
+void COverlayDB::copyToClipboard(bool deleteSelection)
+{
+    IOverlay * ovl = highlightedOverlay();
+
+    if(ovl == 0)
+    {
+        return;
+    }
+
+
+    QClipboard *clipboard = QApplication::clipboard();
+    CQlb qlb(this);
+
+
+    COverlayDistance * dist = qobject_cast<COverlayDistance*>(ovl);
+    if(dist && dist->selectedPoints.size() > 1)
+    {
+        int idx;
+        const QList<int>& selectedPoints = dist->selectedPoints;
+        QList<COverlayDistance::pt_t> pts;
+
+        foreach(idx,selectedPoints)
+        {
+            pts << dist->points[idx];
+        }
+
+
+        COverlayDistance dist2("", "", dist->speed, pts, this);
+
+        qlb << dist2;
+
+    }
+    else
+    {
+        qlb << *ovl;
+    }
+
+    QBuffer buffer;
+    qlb.save(&buffer);
+    QMimeData *md = new QMimeData;
+    buffer.open(QIODevice::ReadOnly);
+    md->setData("qlandkartegt/qlb",buffer.readAll());
+    buffer.close();
+    clipboard->clear();
+    clipboard->setMimeData(md);
+
+}
+
+void COverlayDB::pasteFromClipboard()
+{
+    QClipboard *clipboard = QApplication::clipboard();
+    qDebug() << clipboard->mimeData()->formats();
+    if (clipboard->mimeData()->hasFormat("qlandkartegt/qlb"))
+    {
+        QBuffer buffer;
+        buffer.open(QIODevice::WriteOnly);
+        buffer.write(clipboard->mimeData()->data("qlandkartegt/qlb"));
+        buffer.close();
+        CQlb qlb(this);
+        qlb.load(&buffer);
+
+        addOverlaysAsDuplicate = true;
+        loadQLB(qlb);
+        addOverlaysAsDuplicate = false;
+
+        emit sigModified();
+    }
+}
+
+void COverlayDB::highlightOverlay(const QString& key)
+{
+    QMap<QString,IOverlay*>::iterator ovl = overlays.begin();
+    while(ovl != overlays.end())
+    {
+        (*ovl)->setHighlight(false);
+        ++ovl;
+    }
+
+    if(overlays.contains(key))
+    {
+        IOverlay * ovl = overlays[key];
+
+        if((ovl->type == "Distance") && overlayDistanceEditWidget)
+        {
+            delete overlayDistanceEditWidget;
+            overlayDistanceEditWidget = new COverlayDistanceEditWidget(theMainWindow->getCanvas(), qobject_cast<COverlayDistance*>(ovl));
+            theMainWindow->setTempWidget(overlayDistanceEditWidget, tr("Overlay"));
+        }
+        else if(overlayDistanceEditWidget)
+        {
+            delete overlayDistanceEditWidget;
+        }
+
+        ovl->setHighlight(true);
+    }
+
+    emit sigChanged();
+
+}
+
+IOverlay* COverlayDB::highlightedOverlay()
+{
+
+    QMap<QString,IOverlay*>::iterator ovl = overlays.begin();
+    while(ovl != overlays.end())
+    {
+        if((*ovl)->isHighlighted()) return *ovl;
+        ++ovl;
+    }
+    return 0;
+
+}
+
+void COverlayDB::combineDistOvl()
+{
+    CDlgCombineDistOvl dlg(0);
+    dlg.exec();
+
+}
