@@ -20,7 +20,9 @@
 #ifndef COVERLAYDB_H
 #define COVERLAYDB_H
 
+
 #include "IDB.h"
+#include "COverlayDistance.h"
 
 #include <QMap>
 #include <projects.h>
@@ -38,6 +40,7 @@ class COverlayTextBox;
 class COverlayDistance;
 class QMenu;
 
+
 class COverlayDB : public IDB
 {
     Q_OBJECT;
@@ -50,25 +53,25 @@ class COverlayDB : public IDB
         void draw(QPainter& p, const QRect& r, bool& needsRedraw);
 
         void loadGPX(CGpx& gpx);
-        void saveGPX(CGpx& gpx);
+        void saveGPX(CGpx& gpx, const QStringList& keys);
         void loadQLB(CQlb& qlb);
         void saveQLB(CQlb& qlb);
-        void upload(){};
-        void download(){};
+        void upload(const QStringList&){}
+        void download(){}
         void clear();
         int count(){return overlays.size();}
 
         /// get iterator access to track point list
-        QMap<QString,IOverlay*> ::iterator begin(){return overlays.begin();}
+        QMap<QString,IOverlay*>::iterator begin(){return overlays.begin();}
         /// get iterator access to track point list
-        QMap<QString,IOverlay*> ::iterator end(){return overlays.end();}
+        QMap<QString,IOverlay*>::iterator end(){return overlays.end();}
 
         /// delete several overlays by their keys
         void delOverlays(const QStringList& keys);
 
-        COverlayText * addText(const QString& text, const QRect& rect);
-        COverlayTextBox * addTextBox(const QString& text, double lon, double lat, const QPoint& anchor, const QRect& rect);
-        COverlayDistance * addDistance(const QString& name, const QString& comment, const QList<XY>& pts);
+        COverlayText * addText(const QString& text, const QRect& rect, const QString& key = QString());
+        COverlayTextBox * addTextBox(const QString& text, double lon, double lat, const QPoint& anchor, const QRect& rect, const QString& key = QString());
+        COverlayDistance * addDistance(const QString& name, const QString& comment, double speed, const QList<COverlayDistance::pt_t>& pts, const QString& key = QString());
 
         void customMenu(const QString& key, QMenu& menu);
 
@@ -76,13 +79,33 @@ class COverlayDB : public IDB
 
         IOverlay * getOverlayByKey(const QString& key);
 
+        void highlightOverlay(const QString& key);
+
+        /// get highlighted Overlay
+        /**
+            <b>WARNING</b> The object referenced by the returned
+            pointer might be subject to destruction at any time.
+            Thus you must use it temporarily or store it by a
+            QPointer object.
+
+            @return A pointer to the current highlighted track or 0.
+        */
+        IOverlay * highlightedOverlay();
+
+
+        void copyToClipboard(bool deleteSelection = false);
+        void pasteFromClipboard();
+
+        void combineDistOvl();
+
     private:
         friend class CMainWindow;
         friend class COverlayToolWidget;
         COverlayDB(QTabWidget * tb, QObject * parent);
-
         static COverlayDB * m_self;
 
         QMap<QString,IOverlay*> overlays;
+
+        bool addOverlaysAsDuplicate;
 };
 #endif                           //COVERLAYDB_H
