@@ -18,6 +18,7 @@
 **********************************************************************************************/
 
 #include "COverlayDistance.h"
+#include "COverlayDistanceEditWidget.h"
 #include "CMapDB.h"
 #include "IMap.h"
 #include "GeoMath.h"
@@ -28,7 +29,6 @@
 #include "CTrack.h"
 #include "CRouteDB.h"
 #include "CRoute.h"
-#include "CDlgEditDistance.h"
 #include "CMegaMenu.h"
 #include "CDlgConvertToTrack.h"
 
@@ -39,17 +39,21 @@ bool operator==(const XY& p1, const XY& p2)
     return (p1.u == p2.u) && (p1.v == p2.v);
 }
 
+QPointer<COverlayDistanceEditWidget> overlayDistanceEditWidget;
 
-COverlayDistance::COverlayDistance(const QString& name, const QString& comment, const QList<XY>& pts, QObject * parent)
+COverlayDistance::COverlayDistance(const QString& name, const QString& comment, double speed, const QList<pt_t>& pts, QObject * parent)
 : IOverlay(parent, "Distance", QPixmap(":/icons/iconDistance16x16"))
 , points(pts)
 , thePoint(0)
 , name(name)
 , comment(comment)
 , distance(0)
+, speed(speed)
 , doSpecialCursor(false)
 , doMove(false)
 , doFuncWheel(false)
+, addType(eNone)
+, isEdit(false)
 {
 
     rectDel  = QRect(0,0,16,16);
@@ -58,6 +62,15 @@ COverlayDistance::COverlayDistance(const QString& name, const QString& comment,
     rectAdd2 = QRect(32,32,16,16);
 
     calcDistance();
+
+    if(pts.size() == 1)
+    {
+        points.append(points[0]);
+        thePoint    = &points[1];
+        doMove      = true;
+        addType     = eAtEnd;
+        doFuncWheel = false;
+    }
 }
 
 
@@ -75,13 +88,14 @@ void COverlayDistance::save(QDataStream& s)
     {
         s << pt.u << pt.v;
     }
-
+    s << speed;
+    s << key();
 }
 
 
 void COverlayDistance::load(QDataStream& s)
 {
-    XY pt;
+    pt_t pt;
     int size;
 
     points.clear();
@@ -90,8 +104,11 @@ void COverlayDistance::load(QDataStream& s)
     for(int i = 0; i < size; ++i)
     {
         s >> pt.u >> pt.v;
+        pt.idx = i;
         points << pt;
     }
+    s >> speed;
+    s >> _key_;
 
 }
 
@@ -101,6 +118,8 @@ QString COverlayDistance::getInfo()
     QString info;
     QString val, unit;
 
+    IUnit::self().meter2distance(distance, val, unit);
+
     if(!name.isEmpty())
     {
         info += name + "\n";
@@ -110,8 +129,26 @@ QString COverlayDistance::getInfo()
         info += comment + "\n";
     }
 
-    IUnit::self().meter2distance(distance, val, unit);
     info += tr("Length: %1 %2").arg(val).arg(unit);
+
+    if(speed > 0)
+    {
+        info += "\n" + QString::number(speed * IUnit::self().speedfactor)  + IUnit::self().speedunit + " -> ";
+
+        double ttime = val.toDouble() * 3600 / (speed * IUnit::self().speedfactor);
+        quint32 days = ttime / 86400;
+
+        QTime time;
+        time = time.addSecs(ttime);
+        if(days)
+        {
+            info += tr("%1:").arg(days) + time.toString("HH:mm") + "h";
+        }
+        else
+        {
+            info += time.toString("HH:mm") + "h";
+        }
+    }
     return info;
 }
 
@@ -119,7 +156,7 @@ QString COverlayDistance::getInfo()
 bool COverlayDistance::isCloseEnough(const QPoint& pt)
 {
     IMap& map = CMapDB::self().getMap();
-    QList<XY>::iterator p = points.begin();
+    QList<pt_t>::iterator p = points.begin();
 
     if(doFuncWheel)
     {
@@ -186,6 +223,8 @@ void COverlayDistance::mouseMoveEvent(QMouseEvent * e)
     QPoint pos  = e->pos();
     QPoint pos1 = e->pos();
 
+    subline.clear();
+
     if(thePoint)
     {
         XY pt = *thePoint;
@@ -194,10 +233,12 @@ void COverlayDistance::mouseMoveEvent(QMouseEvent * e)
 
         if(doMove)
         {
-            XY pt;
-            pt.u = pos.x();
-            pt.v = pos.y();
+            pt_t pt;
+            pt.idx  = thePoint->idx;
+            pt.u    = pos.x();
+            pt.v    = pos.y();
             map.convertPt2Rad(pt.u, pt.v);
+
             *thePoint = pt;
             theMainWindow->getCanvas()->update();
         }
@@ -217,38 +258,248 @@ void COverlayDistance::mouseMoveEvent(QMouseEvent * e)
                 doSpecialCursor = false;
             }
         }
+
+        if(addType != eNone)
+        {
+            // find subline between last steady point and current point
+            double u1, v1, u2, v2;
+            IMap& map = CMapDB::self().getMap();
+
+            if(*thePoint == points.last())
+            {
+                u1 = (points.end() - 2)->u;
+                v1 = (points.end() - 2)->v;
+            }
+            else if(*thePoint == points.first())
+            {
+                u1 = (points.begin() + 1)->u;
+                v1 = (points.begin() + 1)->v;
+            }
+            else
+            {
+                int idx = points.indexOf(*thePoint);
+
+                if(addType == eAfter)
+                {
+                    idx--;
+                }
+                else
+                {
+                    idx++;
+                }
+
+                u1 = (points.begin() + idx)->u;
+                v1 = (points.begin() + idx)->v;
+            }
+
+            map.convertRad2Pt(u1,v1);
+            QPoint pt1(u1, v1);
+
+            u2 = thePoint->u;
+            v2 = thePoint->v;
+
+            map.convertRad2Pt(u2,v2);
+            QPoint pt2(u2, v2);
+
+
+            CMapDB::self().getMap().getClosePolyline(pt2, 10, leadline);
+
+            if(!leadline.isEmpty())
+            {
+                GPS_Math_SubPolyline(pt1, pt2, 10, leadline, subline);
+            }
+        }
     }
+
 }
 
 
 void COverlayDistance::mousePressEvent(QMouseEvent * e)
 {
     if(thePoint == 0) return;
+    IMap& map   = CMapDB::self().getMap();
 
     if(e->button() == Qt::LeftButton)
     {
         if(doMove)
         {
-            doMove      = false;
-            thePoint    = 0;
+            if(*thePoint == points.last() && addType == eAtEnd)
+            {
+                const int size = subline.size();
+                if(size < 2)
+                {
+                    pt_t pt;
+                    pt.u    = e->pos().x();
+                    pt.v    = e->pos().y();
+                    map.convertPt2Rad(pt.u, pt.v);
+
+                    points.push_back(pt);
+                }
+                else
+                {
+                    pt_t pt;
+                    pt.u = subline[1].x();
+                    pt.v = subline[1].y();
+                    map.convertPt2Rad(pt.u, pt.v);
+
+                    *thePoint = pt;
+
+                    for(int i = 2; i < size; i++)
+                    {
+                        pt.u = subline[i].x();
+                        pt.v = subline[i].y();
+                        map.convertPt2Rad(pt.u, pt.v);
+
+                        points.push_back(pt);
+                    }
+
+                    points.push_back(pt);
+
+                }
+                thePoint = &points.last();
+            }
+            else if(*thePoint == points.first() && addType == eAtEnd)
+            {
+                const int size = subline.size();
+                if(size < 2)
+                {
+
+                    pt_t pt;
+                    pt.u = e->pos().x();
+                    pt.v = e->pos().y();
+                    map.convertPt2Rad(pt.u, pt.v);
+
+                    points.push_front(pt);
+                }
+                else
+                {
+                    pt_t pt;
+                    pt.u = subline[1].x();
+                    pt.v = subline[1].y();
+                    map.convertPt2Rad(pt.u, pt.v);
+
+                    *thePoint = pt;
+
+                    for(int i = 2; i < size; i++)
+                    {
+                        pt.u = subline[i].x();
+                        pt.v = subline[i].y();
+                        map.convertPt2Rad(pt.u, pt.v);
+
+                        points.push_front(pt);
+                    }
+
+                    points.push_front(pt);
+                }
+                thePoint = &points.first();
+            }
+            else if(addType != eNone)
+            {
+                pt_t pt;
+                const int size = subline.size();
+                int idx = points.indexOf(*thePoint);
+
+                if(size > 2)
+                {
+                    if(addType == eAfter)
+                    {
+                        pt.u = subline[0].x();
+                        pt.v = subline[0].y();
+                        map.convertPt2Rad(pt.u, pt.v);
+
+                        points[idx - 1] = pt;
+
+                        pt.u = subline[size - 1].x();
+                        pt.v = subline[size - 1].y();
+                        map.convertPt2Rad(pt.u, pt.v);
+
+                        points[idx] = pt;
+
+                        for(int i = 1; i < size - 1; i++)
+                        {
+                            pt.u = subline[i].x();
+                            pt.v = subline[i].y();
+                            map.convertPt2Rad(pt.u, pt.v);
+
+                            points.insert(idx - 1 + i,pt);
+                        }
+                        idx += size - 2;
+                    }
+                    else
+                    {
+                        pt.u = subline[0].x();
+                        pt.v = subline[0].y();
+                        map.convertPt2Rad(pt.u, pt.v);
+
+                        points[idx + 1] = pt;
+
+                        pt.u = subline[size - 1].x();
+                        pt.v = subline[size - 1].y();
+                        map.convertPt2Rad(pt.u, pt.v);
+
+                        points[idx] = pt;
+
+                        for(int i = 1; i < size - 1; i++)
+                        {
+                            pt.u = subline[i].x();
+                            pt.v = subline[i].y();
+                            map.convertPt2Rad(pt.u, pt.v);
+
+                            points.insert(idx+1,pt);
+                        }
+                    }
+                }
+
+                if(addType == eAfter)
+                {
+                    idx++;
+                }
+
+
+                pt.u = e->pos().x();
+                pt.v = e->pos().y();
+                map.convertPt2Rad(pt.u, pt.v);
+                points.insert(idx,pt);
+
+                thePoint    = &points[idx];
+            }
+            else
+            {
+                pt_t pt;
+                pt.u = e->pos().x();
+                pt.v = e->pos().y();
+                map.convertPt2Rad(pt.u, pt.v);
+
+                *thePoint = pt;
+
+                doMove      = false;
+                addType     = eNone;
+                thePoint    = 0;
+
+            }
+
+            subline.clear();
+
             calcDistance();
             theMainWindow->getCanvas()->update();
 
-            QApplication::restoreOverrideCursor();
-
             emit sigChanged();
             return;
         }
 
         if(!doFuncWheel)
         {
+            selectedPoints.clear();
+            selectedPoints << points.indexOf(*thePoint);
+            emit sigSelectionChanged();
+
             doFuncWheel = true;
             theMainWindow->getCanvas()->update();
             return;
         }
 
         QPoint pos1 = e->pos();
-        IMap& map   = CMapDB::self().getMap();
+
 
         XY pt = *thePoint;
         map.convertRad2Pt(pt.u, pt.v);
@@ -264,7 +515,7 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
 
             if(points.isEmpty())
             {
-                QStringList keys(key);
+                QStringList keys(key());
                 COverlayDB::self().delOverlays(keys);
             }
             calcDistance();
@@ -278,6 +529,8 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
             QApplication::setOverrideCursor(QCursor(QPixmap(":/cursors/cursorMoveWpt"),0,0));
             doMove      = true;
             doFuncWheel = false;
+
+            savePoint = *thePoint;
         }
         else if(rectAdd1.contains(pos1))
         {
@@ -285,7 +538,7 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
 
             if(idx == -1) return;
 
-            XY pt;
+            pt_t pt;
             pt.u = e->pos().x();
             pt.v = e->pos().y();
             map.convertPt2Rad(pt.u, pt.v);
@@ -293,6 +546,7 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
 
             thePoint    = &points[idx];
             doMove      = true;
+            addType     = eBefore;
             doFuncWheel = false;
 
             theMainWindow->getCanvas()->update();
@@ -305,7 +559,7 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
 
             idx++;
 
-            XY pt;
+            pt_t pt;
             pt.u = e->pos().x();
             pt.v = e->pos().y();
             map.convertPt2Rad(pt.u, pt.v);
@@ -313,6 +567,7 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
 
             thePoint    = &points[idx];
             doMove      = true;
+            addType     = eAfter;
             doFuncWheel = false;
 
             theMainWindow->getCanvas()->update();
@@ -328,41 +583,41 @@ void COverlayDistance::mousePressEvent(QMouseEvent * e)
     {
         if(doMove)
         {
-            doMove      = false;
 
-            points.removeOne(*thePoint);
+            if(addType != eNone)
+            {
+                points.removeOne(*thePoint);
+            }
+            else
+            {
+                *thePoint = savePoint;
+            }
             thePoint = 0;
 
             calcDistance();
             theMainWindow->getCanvas()->update();
             emit sigChanged();
 
-
-//            if (savePoint.u != OVL_NOFLOAT && savePoint.v != OVL_NOFLOAT)
-//            {
-//                *thePoint   = savePoint;
-//                thePoint    = 0;
-//
-//                calcDistance();
-//                theMainWindow->getCanvas()->update();
-//
-//                emit sigChanged();
-//            }
+            doMove      = false;
+            addType     = eNone;
+            subline.clear();
 
             QApplication::restoreOverrideCursor();
             return;
         }
+    }
 
+    selectedPoints.clear();
+    if(addType == eNone)
+    {
+        emit sigSelectionChanged();
     }
 }
 
 
 void COverlayDistance::mouseReleaseEvent(QMouseEvent * e)
 {
-    //     QPoint pos = e->pos();
-    //     IMap& map  = CMapDB::self().getMap();
-    //
-    //     emit sigChanged();
+
 }
 
 
@@ -372,33 +627,129 @@ void COverlayDistance::draw(QPainter& p)
 
     IMap& map = CMapDB::self().getMap();
 
-    QPixmap icon(":/icons/bullet_blue.png");
+    QPixmap icon_blue(":/icons/small_bullet_blue.png");
+    QPixmap icon_red(":/icons/small_bullet_red.png");
+    QPixmap icon_BigRed(":/icons/bullet_red.png");
     XY pt1, pt2;
-    pt1 = points.first();
+
+    int i;
+    int start   = 0;
+    int stop    = points.count();
+    int skip    = -1;
+
+
+    // if there is an active subline fine tune start and stop index
+    // to make the subline replace the first of last line segment
+    if(thePoint && !subline.isEmpty())
+    {
+        if(*thePoint == points.last() )
+        {
+            stop -= 1;
+        }
+        else if(*thePoint == points.first())
+        {
+            start += 1;
+        }
+
+
+        int idx = points.indexOf(*thePoint);
+
+        if(addType == eAfter)
+        {
+            skip = idx;
+        }
+        else
+        {
+            skip = idx + 1;
+        }
+    }
+
+    pt1 = points[start];
     map.convertRad2Pt(pt1.u, pt1.v);
 
-    for(int i = 1; i < points.count(); i++)
+    // draw the lines
+    for(i = start + 1; i < stop; i++)
     {
+
         pt2 = points[i];
         map.convertRad2Pt(pt2.u, pt2.v);
 
-        p.setPen(QPen(Qt::white, 5));
-        p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
-        p.setPen(QPen(Qt::darkBlue, 3));
-        p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
-        p.setPen(QPen(Qt::white, 1));
-        p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
-
-        p.drawPixmap(pt2.u - 5, pt2.v - 5, icon);
-
+        if(i != skip)
+        {
+            if(highlight)
+            {
+                p.setPen(QPen(Qt::white, 7));
+                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
+                p.setPen(QPen(Qt::blue, 5));
+                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
+                p.setPen(QPen(Qt::white, 1));
+                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
+            }
+            else
+            {
+                p.setPen(QPen(Qt::white, 5));
+                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
+                p.setPen(QPen(Qt::darkBlue, 3));
+                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
+                p.setPen(QPen(Qt::white, 1));
+                p.drawLine(pt1.u, pt1.v, pt2.u, pt2.v);
+            }
+        }
         pt1 = pt2;
     }
 
-    for(int i = 0; i < points.count(); i++)
+    // draw the points
+    for(i = start; i < stop; i++)
     {
         pt2 = points[i];
+
         map.convertRad2Pt(pt2.u, pt2.v);
-        p.drawPixmap(pt2.u - 5, pt2.v - 5, icon);
+        p.drawPixmap(pt2.u - 4, pt2.v - 4, icon_blue);
+    }
+
+    // overlay _the_ point with a red bullet
+    if(thePoint)
+    {
+        pt2 = *thePoint;
+        map.convertRad2Pt(pt2.u, pt2.v);
+        p.drawPixmap(pt2.u - 4, pt2.v - 4, icon_red);
+    }
+
+
+    // if there is a subline draw it
+    if(!subline.isEmpty())
+    {
+
+        p.setPen(QPen(Qt::magenta, 3));
+        p.drawPolyline(leadline);
+
+        if(highlight)
+        {
+            p.setPen(QPen(Qt::white, 7));
+            p.drawPolyline(subline);
+            p.setPen(QPen(Qt::blue, 5));
+            p.drawPolyline(subline);
+            p.setPen(QPen(Qt::white, 1));
+            p.drawPolyline(subline);
+        }
+        else
+        {
+            p.setPen(QPen(Qt::white, 5));
+            p.drawPolyline(subline);
+            p.setPen(QPen(Qt::darkBlue, 3));
+            p.drawPolyline(subline);
+            p.setPen(QPen(Qt::white, 1));
+            p.drawPolyline(subline);
+        }
+
+
+        p.setPen(Qt::black);
+        for(i = 1; i < (subline.size() - 1); i++)
+        {
+            p.drawPixmap(subline[i] - QPoint(4,4), icon_red);
+        }
+
+
     }
 
     if(thePoint && !doMove)
@@ -413,8 +764,6 @@ void COverlayDistance::draw(QPainter& p)
             p.setBrush(QColor(255,255,255,200));
             p.drawEllipse(pt2.u - 35, pt2.v - 35, 70, 70);
 
-            p.drawPixmap(pt2.u - 5, pt2.v - 5, QPixmap(":/icons/bullet_red.png"));
-
             p.save();
             p.translate(pt2.u - 24, pt2.v - 24);
             p.drawPixmap(rectDel, QPixmap(":/icons/iconClear16x16.png"));
@@ -466,15 +815,19 @@ void COverlayDistance::draw(QPainter& p)
             p.drawEllipse(pt2.u - 8, pt2.v - 8, 16, 16);
         }
     }
+
+    // overlay points with the selected point icon
+    foreach(i, selectedPoints)
+    {
+        XY pt = points[i];
+
+        map.convertRad2Pt(pt.u, pt.v);
+        p.drawPixmap(pt.u - 6, pt.v - 6, icon_BigRed);
+    }
+
 }
 
 
-void COverlayDistance::addPoint(XY& pt)
-{
-    points << pt;
-    calcDistance();
-    emit sigChanged();
-}
 
 
 void COverlayDistance::calcDistance()
@@ -487,13 +840,14 @@ void COverlayDistance::calcDistance()
     }
 
     double a1,a2;
-    XY pt1, pt2;
+    pt_t pt1, pt2;
     pt1 = points.first();
+    points[0].idx = 0;
 
     for(int i = 1; i < points.count(); i++)
     {
+        points[i].idx = i;
         pt2 = points[i];
-
         distance += ::distance(pt1, pt2, a1, a2);
 
         pt1 = pt2;
@@ -504,9 +858,10 @@ void COverlayDistance::calcDistance()
 
 void COverlayDistance::customMenu(QMenu& menu)
 {
+    menu.addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit..."),this,SLOT(slotEdit()));
     menu.addAction(QPixmap(":/icons/iconTrack16x16.png"),tr("Make Track"),this,SLOT(slotToTrack()));
     menu.addAction(QPixmap(":/icons/iconRoute16x16.png"),tr("Make Route"),this,SLOT(slotToRoute()));
-    menu.addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit..."),this,SLOT(slotEdit()));
+
 }
 
 
@@ -514,7 +869,6 @@ void COverlayDistance::slotToTrack()
 {
     if(points.isEmpty()) return;
 
-    IMap& map       = CMapDB::self().getDEM();
     CTrack * track  = new CTrack(&CTrackDB::self());
 
     track->name = name;
@@ -522,6 +876,7 @@ void COverlayDistance::slotToTrack()
     double dist, d, delta = 10.0, a1 , a2;
     XY pt1, pt2, ptx;
     CTrack::pt_t pt;
+    CDlgConvertToTrack::EleMode_e eleMode;
 
     CDlgConvertToTrack dlg(0);
     if(dlg.exec() == QDialog::Rejected)
@@ -529,7 +884,8 @@ void COverlayDistance::slotToTrack()
         return;
     }
 
-    delta = dlg.getDelta();
+    delta   = dlg.getDelta();
+    eleMode = dlg.getEleMode();
 
     if(delta == -1)
     {
@@ -539,7 +895,6 @@ void COverlayDistance::slotToTrack()
             pt2 = points[i];
             pt.lon = pt2.u * RAD_TO_DEG;
             pt.lat = pt2.v * RAD_TO_DEG;
-            pt.ele = map.getElevation(pt2.u, pt2.v);
             *track << pt;
         }
     }
@@ -554,7 +909,6 @@ void COverlayDistance::slotToTrack()
         pt1 = points.first();
         pt.lon = pt1.u * RAD_TO_DEG;
         pt.lat = pt1.v * RAD_TO_DEG;
-        pt.ele = map.getElevation(pt1.u, pt1.v);
         *track << pt;
 
         // all other points
@@ -572,7 +926,6 @@ void COverlayDistance::slotToTrack()
                 ptx = GPS_Math_Wpt_Projection(pt1, d, a1);
                 pt.lon = ptx.u * RAD_TO_DEG;
                 pt.lat = ptx.v * RAD_TO_DEG;
-                pt.ele = map.getElevation(ptx.u, ptx.v);
                 *track << pt;
 
                 d += delta;
@@ -581,14 +934,22 @@ void COverlayDistance::slotToTrack()
             // and finally the next point
             pt.lon = pt2.u * RAD_TO_DEG;
             pt.lat = pt2.v * RAD_TO_DEG;
-            pt.ele = map.getElevation(pt2.u, pt2.v);
             *track << pt;
 
             pt1 = pt2;
         }
     }
-    CTrackDB::self().addTrack(track, false);
 
+    if(eleMode == CDlgConvertToTrack::eLocal)
+    {
+        track->replaceElevationByLocal();
+    }
+    else if(eleMode == CDlgConvertToTrack::eRemote)
+    {
+        track->replaceElevationByRemote();
+    }
+
+    CTrackDB::self().addTrack(track, false);
     CMegaMenu::self().switchByKeyWord("Tracks");
 }
 
@@ -619,10 +980,9 @@ void COverlayDistance::slotToRoute()
 
 void COverlayDistance::slotEdit()
 {
-    CDlgEditDistance dlg(*this, 0);
-    dlg.exec();
-
-    emit sigChanged();
+    if(!overlayDistanceEditWidget.isNull()) delete overlayDistanceEditWidget;
+    overlayDistanceEditWidget = new COverlayDistanceEditWidget(theMainWindow->getCanvas(), this);
+    theMainWindow->setTempWidget(overlayDistanceEditWidget, tr("Overlay"));
 }
 
 
@@ -653,6 +1013,7 @@ void COverlayDistance::looseFocus()
         doSpecialCursor = false;
     }
     doMove          = false;
+    addType         = eNone;
     doFuncWheel     = false;
 }
 
@@ -676,3 +1037,35 @@ QRectF COverlayDistance::getBoundingRectF()
     return QRectF(QPointF(west * RAD_TO_DEG,north * RAD_TO_DEG),QPointF(east * RAD_TO_DEG,south * RAD_TO_DEG));
 
 }
+
+void COverlayDistance::delPointsByIdx(const QList<int>& idx)
+{
+    int i;
+
+    foreach(i, idx)
+    {
+        QList<pt_t>::iterator pt = points.begin();
+        while(pt != points.end())
+        {
+            if(pt->idx == i)
+            {
+                pt = points.erase(pt);
+            }
+            else
+            {
+                pt++;
+            }
+        }
+    }
+
+    thePoint    = 0;
+    doMove      = false;
+    addType     = eNone;
+    doFuncWheel = false;
+
+    selectedPoints.clear();
+
+    calcDistance();
+    emit sigChanged();
+}
+
