@@ -18,6 +18,7 @@
 **********************************************************************************************/
 #include "COverlayToolWidget.h"
 #include "COverlayDB.h"
+#include "COverlayDistanceEditWidget.h"
 #include "IOverlay.h"
 #include "CMapDB.h"
 
@@ -25,6 +26,7 @@
 
 COverlayToolWidget::COverlayToolWidget(QTabWidget * parent)
 : QWidget(parent)
+, originator(false)
 {
     setupUi(this);
     setObjectName("Overlay");
@@ -34,6 +36,8 @@ COverlayToolWidget::COverlayToolWidget(QTabWidget * parent)
 
     connect(&COverlayDB::self(), SIGNAL(sigChanged()), this, SLOT(slotDBChanged()));
     connect(listOverlays,SIGNAL(itemDoubleClicked(QListWidgetItem*) ),this,SLOT(slotItemDoubleClicked(QListWidgetItem*)));
+    connect(listOverlays,SIGNAL(itemClicked(QListWidgetItem*) ),this,SLOT(slotItemClicked(QListWidgetItem*)));
+    connect(listOverlays,SIGNAL(itemSelectionChanged()),this,SLOT(slotSelectionChanged()));
 
     connect(listOverlays,SIGNAL(customContextMenuRequested(const QPoint&)),this,SLOT(slotContextMenu(const QPoint&)));
 }
@@ -47,6 +51,8 @@ COverlayToolWidget::~COverlayToolWidget()
 
 void COverlayToolWidget::slotDBChanged()
 {
+    if(originator) return;
+
     listOverlays->clear();
 
     QMap<QString, IOverlay*>& overlays                  = COverlayDB::self().overlays;
@@ -76,12 +82,35 @@ void COverlayToolWidget::slotItemDoubleClicked(QListWidgetItem * item)
     overlays[key]->makeVisible();
 }
 
+void COverlayToolWidget::slotItemClicked(QListWidgetItem * item)
+{
+    originator = true;
+    COverlayDB::self().highlightOverlay(item->data(Qt::UserRole).toString());
+    originator = false;
+}
+
+void COverlayToolWidget::slotSelectionChanged()
+{
+    if(listOverlays->hasFocus() && listOverlays->selectedItems().isEmpty())
+    {
+        COverlayDB::self().highlightOverlay("");
+        if(overlayDistanceEditWidget)
+        {
+            delete overlayDistanceEditWidget;
+        }
+    }
+}
+
 
 void COverlayToolWidget::slotContextMenu(const QPoint& pos)
 {
     QListWidgetItem * item = listOverlays->currentItem();
     if(item)
     {
+        originator = true;
+        COverlayDB::self().highlightOverlay(item->data(Qt::UserRole).toString());
+        originator = false;
+
         QPoint p = listOverlays->mapToGlobal(pos);
 
         QMenu contextMenu;
@@ -91,7 +120,7 @@ void COverlayToolWidget::slotContextMenu(const QPoint& pos)
         //            contextMenu.addAction(QPixmap(),tr("<---->"));
         //        }
         contextMenu.addAction(QPixmap(":/icons/iconZoomArea16x16.png"),tr("Zoom to fit"),this,SLOT(slotZoomToFit()));
-        contextMenu.addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Delete"),this,SLOT(slotDelete()),Qt::Key_Delete);
+        contextMenu.addAction(QPixmap(":/icons/iconClear16x16.png"),tr("Delete"),this,SLOT(slotDelete()),Qt::CTRL + Qt::Key_Delete);
 
         contextMenu.exec(p);
     }
@@ -134,7 +163,6 @@ void COverlayToolWidget::slotDelete()
     foreach(item,items)
     {
         keys << item->data(Qt::UserRole).toString();
-        delete item;
     }
     COverlayDB::self().delOverlays(keys);
 }
