@@ -46,6 +46,7 @@ class CResources : public QObject
 
         /// get pointer to current device handler
         IDevice * device();
+        QString charset();
 
         /// the font used for text on the map
         const QFont& getMapFont(){return m_mapfont;}
@@ -57,6 +58,7 @@ class CResources : public QObject
         QString pathMaps;
 
         bool flipMouseWheel(){return m_flipMouseWheel;}
+        bool playSound(){return m_playSound;}
 
         signals:
         void sigProxyChanged();
@@ -69,7 +71,7 @@ class CResources : public QObject
 
         static CResources * m_self;
 
-        enum bowser_e
+        enum browser_e
         {
             eFirefox = 0
             ,eKonqueror = 1
@@ -87,7 +89,7 @@ class CResources : public QObject
         QFont m_mapfont;
 
         /// the installed browser type
-        bowser_e m_eBrowser;
+        browser_e m_eBrowser;
         /// command string to start Firefox
         QString cmdFirefox;
         /// command string to start Konqueror
@@ -112,10 +114,14 @@ class CResources : public QObject
         QString m_devSerialPort;
 
         QString m_devType;
+        QString m_devCharset;
 
         /// mouse wheel zoom direction
         bool m_flipMouseWheel;
 
+        /// play sound after finishing transfers
+        bool m_playSound;
+
         /// unit translator object
         QPointer<IUnit> unit;
 };
