@@ -20,8 +20,10 @@
 #include "CTrack.h"
 #include "GeoMath.h"
 #include "CMapDB.h"
+#include "CResources.h"
 
 #include <QtGui>
+#include <QtNetwork/QHttp>
 
 #ifndef _MKSTR_1
 #define _MKSTR_1(x)    #x
@@ -441,8 +443,12 @@ CTrack::CTrack(QObject * parent)
 , ext1Data(false)
 , firstTime(true)
 , m_hide(false)
+, geonames(0)
 {
     ref = 1;
+
+    slotSetupLink();
+    connect(&CResources::self(), SIGNAL(sigProxyChanged()), this, SLOT(slotSetupLink()));
 }
 
 
@@ -451,6 +457,113 @@ CTrack::~CTrack()
 
 }
 
+void CTrack::slotSetupLink()
+{
+    QString url;
+    quint16 port;
+    bool enableProxy;
+
+    enableProxy = CResources::self().getHttpProxy(url,port);
+
+    if(geonames) delete geonames;
+    geonames = new QHttp(this);
+    if(enableProxy)
+    {
+        geonames->setProxy(url,port);
+    }
+    geonames->setHost("ws.geonames.org");
+    connect(geonames,SIGNAL(requestStarted(int)),this,SLOT(slotRequestStarted(int)));
+    connect(geonames,SIGNAL(requestFinished(int,bool)),this,SLOT(slotRequestFinished(int,bool)));
+
+
+}
+
+void CTrack::replaceElevationByLocal()
+{
+    qDebug() << "CTrack::replaceElevationByLocal()";
+    IMap& map       = CMapDB::self().getDEM();
+    const int size = track.size();
+    for(int i = 0; i<size; i++)
+    {
+        track[i].ele = map.getElevation(track[i].lon * DEG_TO_RAD, track[i].lat * DEG_TO_RAD);
+    }
+    rebuild(false);
+    emit sigChanged();
+}
+
+void CTrack::replaceElevationByRemote()
+{    
+    int idx = 0, id;
+    const int size = track.size();
+
+    id2idx.clear();
+
+    while(idx < size)
+    {
+        int s = (size - idx) > 20 ? 20 : (size - idx);
+
+        QStringList lats, lngs;
+        for(int i=0; i < s; i++)
+        {
+            lats << QString::number(track[idx + i].lat,'f', 8);
+            lngs << QString::number(track[idx + i].lon,'f', 8);
+        }
+
+        QUrl url;
+        url.setPath("/srtm3");
+        url.addQueryItem("lats",lats.join(","));
+        url.addQueryItem("lngs",lngs.join(","));
+        id = geonames->get(url.toEncoded( ));
+
+        id2idx[id] = idx;
+
+        idx += s;
+    }
+}
+
+void CTrack::slotRequestStarted(int id)
+{
+//    qDebug() << "void CTrack::slotRequestStarted(int id)" << id;
+}
+
+void CTrack::slotRequestFinished(int id, bool error)
+{
+//    qDebug() << "void CTrack::slotRequestFinished(int id, bool error)" << id << error;
+
+    if(error)
+    {
+        qDebug() << geonames->errorString();
+        return;
+    }
+
+    QString asw = geonames->readAll().simplified();
+
+    if(asw.isEmpty())
+    {
+        return;
+    }
+
+    QString val;
+    QStringList vals = asw.split(" ", QString::SkipEmptyParts);
+
+    if(id2idx.contains(id))
+    {
+        int idx = id2idx[id];
+        foreach(val, vals)
+        {
+            track[idx++].ele = val.toDouble();
+        }
+
+        id2idx.remove(id);
+        if(id2idx.isEmpty())
+        {
+            rebuild(false);
+            emit sigChanged();
+        }
+    }
+}
+
+
 
 QRectF CTrack::getBoundingRectF()
 {
