@@ -1,5 +1,6 @@
 /**********************************************************************************************
     Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2010 Joerg Wunsch <j@uriah.heep.sax.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -46,6 +47,17 @@ typedef __int32 int32_t;
 
 CTrackDB * CTrackDB::m_self = 0;
 
+bool CTrackDB::keyLessThanAlpha(CTrackDB::keys_t&  s1, CTrackDB::keys_t&  s2)
+{
+    return s1.name.toLower() < s2.name.toLower();
+}
+
+bool CTrackDB::keyLessThanTime(keys_t&  s1, keys_t&  s2)
+{
+    return s1.time < s2.time;
+}
+
+
 CTrackDB::CTrackDB(QTabWidget * tb, QObject * parent)
 : IDB(tb,parent)
 , cnt(0)
@@ -257,17 +269,7 @@ void CTrackDB::loadGPX(CGpx& gpx)
                 if(!tmpelem.isNull())
                 {
                     QString timetext = tmpelem.text();
-
-                    QString format = "yyyy-MM-dd'T'hh:mm:ss";
-                    if (timetext.indexOf(".") != -1) format += ".zzz";
-                                 // bugfix for badly coded gpx files
-                    if (timetext.indexOf("Z") != -1) format += "'Z'";
-
-                    QDateTime datetime = QDateTime::fromString(timetext, format);
-                    datetime.setTimeSpec(Qt::UTC);
-
-                    pt.timestamp = datetime.toTime_t();
-                    pt.timestamp_msec = datetime.time().msec();
+                    (void)parseTimestamp(timetext, pt.timestamp, pt.timestamp_msec);
                 }
 
                 tmpelem = trkptmap.value("fix");
@@ -414,19 +416,32 @@ void CTrackDB::loadGPX(CGpx& gpx)
 }
 
 
-void CTrackDB::saveGPX(CGpx& gpx)
+void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
 {
     QString str;
     QDomElement root = gpx.documentElement();
     QMap<QString,CTrack*>::iterator track = tracks.begin();
-    while(track != tracks.end())
+
+
+    QList<keys_t> _keys = this->keys();
+    QList<keys_t>::const_iterator _key = _keys.begin();
+
+    while(_key != _keys.end())
     {
+        CTrack * track = tracks[_key->key];
+
+        if(!keys.isEmpty() && !keys.contains(track->key()))
+        {
+            ++_key;
+            continue;
+        }
+
         QDomElement trk = gpx.createElement("trk");
         root.appendChild(trk);
 
         QDomElement name = gpx.createElement("name");
         trk.appendChild(name);
-        QDomText _name_ = gpx.createTextNode((*track)->getName());
+        QDomText _name_ = gpx.createTextNode(track->getName());
         name.appendChild(_name_);
 
         QDomElement ext = gpx.createElement("extensions");
@@ -438,14 +453,14 @@ void CTrackDB::saveGPX(CGpx& gpx)
         QDomElement color = gpx.createElement("gpxx:DisplayColor");
         gpxx_ext.appendChild(color);
 
-        QString colname = gpx.getTrackColorMap().left((*track)->getColorIdx());
+        QString colname = gpx.getTrackColorMap().left(track->getColorIdx());
         QDomText _color_ = gpx.createTextNode(colname);
         color.appendChild(_color_);
 
         QDomElement trkseg = gpx.createElement("trkseg");
         trk.appendChild(trkseg);
 
-        QList<CTrack::pt_t>& pts = (*track)->getTrackPoints();
+        QList<CTrack::pt_t>& pts = track->getTrackPoints();
         QList<CTrack::pt_t>::const_iterator pt = pts.begin();
         while(pt != pts.end())
         {
@@ -554,7 +569,7 @@ void CTrackDB::saveGPX(CGpx& gpx)
             ++pt;
         }
 
-        ++track;
+        ++_key;
     }
 
 }
@@ -655,14 +670,27 @@ CTrack* CTrackDB::highlightedTrack()
 }
 
 
-void CTrackDB::upload()
+void CTrackDB::upload(const QStringList& keys)
 {
     if(tracks.isEmpty()) return;
 
     IDevice * dev = CResources::self().device();
     if(dev)
     {
-        QList<CTrack*> tmptrks = tracks.values();
+        QList<CTrack*> tmptrks;
+
+        if(keys.isEmpty())
+        {
+            tmptrks = tracks.values();
+        }
+        else
+        {
+            QString key;
+            foreach(key, keys)
+            {
+                tmptrks << tracks[key];
+            }
+        }
         dev->uploadTracks(tmptrks);
     }
 }
@@ -1046,6 +1074,8 @@ void CTrackDB::pasteFromClipboard()
         CQlb qlb(this);
         qlb.load(&buffer);
         loadQLB(qlb, true);
+
+        emit sigModified();
     }
 }
 
@@ -1111,3 +1141,50 @@ void CTrackDB::revertTrack(const QString& key)
     addTrack(tnew, false);
 
 }
+
+QList<CTrackDB::keys_t> CTrackDB::keys()
+{
+    QList<keys_t> k;
+
+    QString k1;
+    QStringList ks = tracks.keys();
+
+    foreach(k1, ks)
+    {
+        QPixmap icon(16,16);
+        keys_t k2;
+        CTrack * track = tracks[k1];
+
+        k2.key      = k1;
+        k2.name     = track->name;
+        k2.comment  = track->comment.left(32);
+        k2.time     = track->track.first().timestamp;
+
+        icon.fill(track->getColor());
+        k2.icon     = icon;
+
+        k << k2;
+    }
+
+    CTrackToolWidget::sortmode_e sortmode = CTrackToolWidget::getSortMode();
+
+    switch(sortmode)
+    {
+        case CTrackToolWidget::eSortByName:
+            qSort(k.begin(), k.end(), CTrackDB::keyLessThanAlpha);
+            break;
+        case CTrackToolWidget::eSortByTime:
+            qSort(k.begin(), k.end(), CTrackDB::keyLessThanTime);
+            break;
+    }
+
+    return k;
+}
+
+CTrack * CTrackDB::getTrackByKey(const QString& key)
+{
+    if(!tracks.contains(key)) return 0;
+
+    return tracks[key];
+
+}
