@@ -86,9 +86,6 @@ CTrackEditWidget::CTrackEditWidget(QWidget * parent)
     tabWidget->removeTab(1);
 #endif
 
-    toolExit->setIcon(QIcon(":/icons/iconExit16x16.png"));
-    connect(toolExit, SIGNAL(clicked()), this, SLOT(close()));
-
     toolGraphDistance->setIcon(QIcon(":/icons/iconGraph16x16.png"));
     connect(toolGraphDistance, SIGNAL(clicked()), this, SLOT(slotToggleStatDistance()));
 
@@ -151,7 +148,7 @@ CTrackEditWidget::CTrackEditWidget(QWidget * parent)
 
 
     contextMenu = new QMenu(this);
-    contextMenu->addAction(actions->getAction("aDeleteTrackSelection"));
+    contextMenu->addAction(actions->getAction("aTrackPurgeSelection"));
     actSplit    = contextMenu->addAction(QPixmap(":/icons/iconEditCut16x16.png"),tr("Split"),this,SLOT(slotSplit()));
     connect(treePoints,SIGNAL(customContextMenuRequested(const QPoint&)),this,SLOT(slotContextMenu(const QPoint&)));
 }
@@ -256,7 +253,7 @@ void CTrackEditWidget::slotSetTrack(CTrack * t)
     if(track)
     {
         disconnect(track,SIGNAL(sigChanged()), this, SLOT(slotUpdate()));
-        disconnect(track,SIGNAL(destroyed(QObject*)), this, SLOT(close()));
+        disconnect(track,SIGNAL(destroyed(QObject*)), this, SLOT(deleteLater()));
 
         // clean view
         QList<CTrack::pt_t>& trkpts           = track->getTrackPoints();
@@ -390,7 +387,7 @@ void CTrackEditWidget::slotSetTrack(CTrack * t)
     }
 
     connect(track,SIGNAL(sigChanged()), this, SLOT(slotUpdate()));
-    connect(track,SIGNAL(destroyed(QObject*)), this, SLOT(close()));
+    connect(track,SIGNAL(destroyed(QObject*)), this, SLOT(deleteLater()));
 
     slotUpdate();
 
@@ -823,12 +820,10 @@ void CTrackEditWidget::slotPurge()
         quint32 idxTrkPt = (*item)->data(0,Qt::UserRole).toUInt();
         if(trkpts[idxTrkPt].flags & CTrack::pt_t::eDeleted)
         {
-            qDebug() << "xx" << idxTrkPt;
             trkpts[idxTrkPt].flags &= ~CTrack::pt_t::eDeleted;
         }
         else
         {
-            qDebug() << "yy"<< idxTrkPt;
             trkpts[idxTrkPt].flags |= CTrack::pt_t::eDeleted;
         }
 
