@@ -20,13 +20,23 @@
 #define CTRACKEDITWIDGET_H
 
 #include <QWidget>
+#include <QObject>
+#include <QBoxLayout>
 #include <QPointer>
+#include <CGpxExtension.h>
+#include <QVBoxLayout>
 #include "ui_ITrackEditWidget.h"
 
 class CTrack;
 class CTrackStatProfileWidget;
 class CTrackStatSpeedWidget;
 class CTrackStatTraineeWidget;
+class QMenu;
+
+#ifdef GPX_EXTENSIONS
+//TODO: Class Defininition
+class CTrackStatExtensionWidget;
+#endif
 
 class CTrackTreeWidgetItem : public QTreeWidgetItem
 {
@@ -63,9 +73,25 @@ class CTrackEditWidget : public QWidget, private Ui::ITrackEditWidget
         void slotToggleStatTime();
         void slotToggleTrainee();
 
+#ifdef GPX_EXTENSIONS
+        //TODO: Deklaration der Methode fr die Extensions Graphen
+        void slotToggleExtensionsGraph();
+        //TODO: eigenes Methdchen
+        void slotSetColumns(bool checked);
+        void slotSetColumnsExt(bool checked);
+#endif
+        void slotGoogleMaps();   //TODO: Google Maps
+                                 //TODO: Kill Tab
+        void slotKillTab(int index);
+
+    protected slots:
+        void slotContextMenu(const QPoint& pos);
+        void slotSplit();
+
     protected:
         void keyPressEvent(QKeyEvent * e);
 
+
     private:
         enum columns_e
         {
@@ -92,5 +118,29 @@ class CTrackEditWidget : public QWidget, private Ui::ITrackEditWidget
         QPointer<CTrackStatSpeedWidget> trackStatSpeedTime;
         QPointer<CTrackStatTraineeWidget> trackStatTrainee;
 
+#ifdef GPX_EXTENSIONS
+                                 //TODO: Namen der extensions
+        QList<QString> names_of_ext;
+        int num_of_ext;          //TODO: Anzahl der extensions
+
+        QList<QCheckBox *> c_boxes;
+
+                                 //TODO: QPointer for tabs to be handled
+        QPointer<CTrackStatExtensionWidget> tab;
+
+                                 //TODO: QList with all extension tabs made for further handling
+        QList<CTrackStatExtensionWidget *> tabs;
+
+        QSpacerItem *Vspace;     //TODO: Spacer Item
+
+        QLabel *label;
+
+        int tabstat;
+        int no_ext_info_stat;
+        int count;
+#endif
+
+        QMenu * contextMenu;
+        QAction * actSplit;
 };
 #endif                           //CTRACKEDITWIDGET_H
