@@ -44,7 +44,7 @@ class CWptDB : public IDB
         /// get iterator access to track point list
         QMap<QString,CWpt*> ::iterator end(){return wpts.end();}
 
-        struct keys_t{QString key; QString name; QString icon; qreal lon; qreal lat; qreal d;};
+        struct keys_t{QString key; QString name; QString comment; QString icon; qreal lon; qreal lat; qreal d;};
 
         /// get all keys in the database
         QList<keys_t> keys();
@@ -72,15 +72,13 @@ class CWptDB : public IDB
         void setProxyDistance(const QStringList& keys, double dist);
 
         void loadGPX(CGpx& gpx);
-        void saveGPX(CGpx& gpx);
+        void saveGPX(CGpx& gpx, const QStringList& keys);
         void loadQLB(CQlb& qlb);
         void saveQLB(CQlb& qlb);
 
-        void upload();
+        void upload(const QStringList& keys);
         void download();
-
         void clear();
-
         void selWptByKey(const QString& key);
 
         int count(){return wpts.count();}
@@ -101,6 +99,13 @@ class CWptDB : public IDB
         };
 #endif
 
+        static bool keyLessThanAlpha(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2);
+        static bool keyLessThanComment(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2);
+        static bool keyLessThanIcon(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2);
+        static bool keyLessThanDistance(CWptDB::keys_t&  s1, CWptDB::keys_t&  s2);
+
+
+
     private:
         friend class CMainWindow;
         friend class CDlgEditWpt;
