@@ -19,6 +19,8 @@
 
 #include "IOverlay.h"
 #include "COverlayDB.h"
+#include "COverlayDistance.h"
+#include "GeoMath.h"
 
 #include <QtGui>
 struct ovl_head_entry_t
@@ -67,15 +69,15 @@ QDataStream& operator >>(QDataStream& s, COverlayDB& db)
 
                 QDataStream s1(&entry->data, QIODevice::ReadOnly);
                 s1.setVersion(QDataStream::Qt_4_5);
-                QString type;
+                QString type, key;
 
                 s1 >> type;
                 if(type == "Text")
                 {
                     QRect rect;
                     QString text;
-                    s1 >> rect >> text;
-                    db.addText(text,rect);
+                    s1 >> rect >> text >> key;
+                    db.addText(text,rect, key);
                 }
                 else if(type == "TextBox")
                 {
@@ -83,23 +85,26 @@ QDataStream& operator >>(QDataStream& s, COverlayDB& db)
                     QPoint pt;
                     QString text;
                     double lon, lat;
-                    s1 >> lon >> lat >> pt >> rect >> text;
-                    db.addTextBox(text, lon, lat, pt, rect);
+                    s1 >> lon >> lat >> pt >> rect >> text >> key;
+                    db.addTextBox(text, lon, lat, pt, rect, key);
                 }
                 else if(type == "Distance")
                 {
+                    float speed;
                     QString name;
                     QString comment;
-                    int size;
-                    XY pt;
-                    QList<XY> points;
+                    int size, idx = 0;
+                    COverlayDistance::pt_t pt;
+                    QList<COverlayDistance::pt_t> points;
                     s1 >> name >> comment >> size;
                     for(int i = 0; i < size; ++i)
                     {
                         s1 >> pt.u >> pt.v;
+                        pt.idx = idx++;
                         points << pt;
                     }
-                    db.addDistance(name, comment, points);
+                    s1 >> speed >> key;
+                    db.addDistance(name, comment, speed, points, key);
                 }
                 break;
             }
@@ -200,7 +205,7 @@ IOverlay::IOverlay(QObject * parent, const QString& type, const QPixmap& icon)
 : QObject(parent)
 , type(type)
 , icon(icon)
-, key(QString("%1_%2").arg(type).arg(count++))
+, highlight(false)
 {
 
 }
@@ -216,3 +221,15 @@ void IOverlay::select(IOverlay * s)
 {
     selected = s;
 }
+
+void IOverlay::genKey()
+{
+    _key_ = QString("%1%2%3").arg(type).arg(QDateTime::currentDateTime().toString()).arg(count++);
+}
+
+
+const QString& IOverlay::key()
+{
+    if(_key_.isEmpty()) genKey();
+    return _key_;
+}
