@@ -59,26 +59,25 @@ class IOverlay : public QObject
         virtual bool mouseActionInProgress(){return false;}
 
         /// get mouse move event when selected
-        virtual void mouseMoveEvent(QMouseEvent * e){};
+        virtual void mouseMoveEvent(QMouseEvent * e){}
         /// get mouse press event when selected
-        virtual void mousePressEvent(QMouseEvent * e){};
+        virtual void mousePressEvent(QMouseEvent * e){}
         /// get mouse release event when selected
-        virtual void mouseReleaseEvent(QMouseEvent * e){};
+        virtual void mouseReleaseEvent(QMouseEvent * e){}
 
         /// save overlay data to datastream
-        virtual void save(QDataStream& s){};
+        virtual void save(QDataStream& s){}
         /// load overlay data from datastream
-        virtual void load(QDataStream& s){};
-
+        virtual void load(QDataStream& s){}
         /// set the static selected pointer
         static void select(IOverlay * s);
 
         /// move map to make overlay visible
-        virtual void makeVisible(){};
+        virtual void makeVisible(){}
 
         virtual void customMenu(QMenu& menu){}
 
-        virtual void looseFocus(){};
+        virtual void looseFocus(){}
 
         virtual QRectF getBoundingRectF(){return QRectF();}
 
@@ -86,17 +85,32 @@ class IOverlay : public QObject
         const QString type;
         /// the overlay icon
         const QPixmap icon;
-        /// the unique overlay key used by the database
-        const QString key;
+        /// get unique track key
+        const QString& key();
+
+
+        void setHighlight(bool on){highlight = on;}
+        bool isHighlighted(){return highlight;}
 
         signals:
         void sigChanged();
 
     protected:
+        friend class COverlayDB;
+        void genKey();
+
         static QPointer<IOverlay> selected;
 
+        /// set true to draw overlay highlighted
+        bool highlight;
+
+        /// the unique overlay key used by the database
+        QString _key_;
+
     private:
         static int count;
+
+
 };
 
 QDataStream& operator >>(QDataStream& s, COverlayDB& db);
